from PyObjCTools.TestSupport import TestCase, min_os_level, max_os_level
import SystemConfiguration
import objc


class TestSCNetworkConfiguration(TestCase):
    def testTypes(self):
        self.assertTrue(
            isinstance(SystemConfiguration.SCNetworkInterfaceRef, objc.objc_class)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.SCBondStatusRef, objc.objc_class)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.SCNetworkProtocolRef, objc.objc_class)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.SCNetworkServiceRef, objc.objc_class)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.SCNetworkSetRef, objc.objc_class)
        )

        self.assertTrue(
            SystemConfiguration.SCBondInterfaceRef
            is SystemConfiguration.SCNetworkInterfaceRef
        )
        self.assertTrue(
            SystemConfiguration.SCVLANInterfaceRef
            is SystemConfiguration.SCNetworkInterfaceRef
        )

    def testConstants(self):
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceType6to4, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeBluetooth, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeBond, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeEthernet, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeFireWire, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeIEEE80211, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeL2TP, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeIrDA, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeModem, str)
        )
        self.assertTrue(isinstance(SystemConfiguration.kSCNetworkInterfaceTypePPP, str))
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypePPTP, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeSerial, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeVLAN, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeWWAN, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkInterfaceTypeIPv4, str)
        )

        self.assertTrue(
            isinstance(
                SystemConfiguration.kSCNetworkInterfaceIPv4,
                SystemConfiguration.SCNetworkInterfaceRef,
            )
        )

        self.assertEqual(SystemConfiguration.kSCBondStatusOK, 0)
        self.assertEqual(SystemConfiguration.kSCBondStatusLinkInvalid, 1)
        self.assertEqual(SystemConfiguration.kSCBondStatusNoPartner, 2)
        self.assertEqual(SystemConfiguration.kSCBondStatusNotInActiveGroup, 3)
        self.assertEqual(SystemConfiguration.kSCBondStatusUnknown, 999)

        self.assertTrue(
            isinstance(SystemConfiguration.kSCBondStatusDeviceAggregationStatus, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCBondStatusDeviceCollecting, str)
        )
        self.assertTrue(
            isinstance(SystemConfiguration.kSCBondStatusDeviceDistributing, str)
        )

        self.assertTrue(isinstance(SystemConfiguration.kSCNetworkProtocolTypeDNS, str))
        self.assertTrue(isinstance(SystemConfiguration.kSCNetworkProtocolTypeIPv4, str))
        self.assertTrue(isinstance(SystemConfiguration.kSCNetworkProtocolTypeIPv6, str))
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkProtocolTypeProxies, str)
        )
        self.assertTrue(isinstance(SystemConfiguration.kSCNetworkProtocolTypeSMB, str))

    @max_os_level("10.11")
    def testConstantsUpto10_12(self):
        self.assertTrue(
            isinstance(SystemConfiguration.kSCNetworkProtocolTypeAppleTalk, str)
        )

    @min_os_level("10.6")
    def testConstants10_5(self):
        self.assertIsInstance(SystemConfiguration.kSCNetworkInterfaceTypeIPSec, str)

    def testFunctions(self):
        r = SystemConfiguration.SCNetworkInterfaceGetTypeID()
        self.assertTrue(isinstance(r, int))

        r = SystemConfiguration.SCNetworkInterfaceCopyAll()
        self.assertTrue(isinstance(r, SystemConfiguration.CFArrayRef))
        self.assertTrue(len(r) > 0)

        for iface in r:
            if SystemConfiguration.SCNetworkInterfaceGetBSDName(iface).startswith("en"):
                break

        r = SystemConfiguration.SCNetworkInterfaceGetSupportedInterfaceTypes(iface)
        self.assertTrue(isinstance(r, SystemConfiguration.CFArrayRef))
        self.assertTrue(isinstance(r[0], str))

        r = SystemConfiguration.SCNetworkInterfaceGetSupportedProtocolTypes(iface)
        self.assertTrue(isinstance(r, SystemConfiguration.CFArrayRef))
        self.assertTrue(isinstance(r[0], str))

        r = SystemConfiguration.SCNetworkInterfaceCreateWithInterface(
            iface, SystemConfiguration.kSCNetworkInterfaceTypeL2TP
        )
        self.assertTrue(
            r is None or isinstance(r, SystemConfiguration.SCNetworkInterfaceRef)
        )

        r = SystemConfiguration.SCNetworkInterfaceGetBSDName(iface)
        self.assertTrue(isinstance(r, str))

        r = SystemConfiguration.SCNetworkInterfaceGetConfiguration(iface)
        self.assertTrue(r is None or isinstance(r, SystemConfiguration.CFDictionaryRef))

        r = SystemConfiguration.SCNetworkInterfaceGetExtendedConfiguration(
            iface, "EAPOL"
        )
        self.assertTrue(r is None or isinstance(r, SystemConfiguration.CFDictionaryRef))

        r = SystemConfiguration.SCNetworkInterfaceGetHardwareAddressString(iface)
        self.assertTrue(isinstance(r, str))

        r = SystemConfiguration.SCNetworkInterfaceGetInterface(iface)
        self.assertTrue(r is None)

        r = SystemConfiguration.SCNetworkInterfaceGetInterfaceType(iface)
        self.assertTrue(isinstance(r, str))

        r = SystemConfiguration.SCNetworkInterfaceGetLocalizedDisplayName(iface)
        self.assertTrue(isinstance(r, str))

        r = SystemConfiguration.SCNetworkInterfaceSetConfiguration(iface, {})
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCNetworkInterfaceSetExtendedConfiguration(
            iface, "OC", {}
        )
        self.assertTrue(r is True or r is False)

        (
            r,
            current,
            active,
            available,
        ) = SystemConfiguration.SCNetworkInterfaceCopyMediaOptions(
            iface, None, None, None, False
        )
        self.assertTrue(r is True)
        self.assertTrue(isinstance(current, SystemConfiguration.CFDictionaryRef))
        self.assertTrue(isinstance(active, SystemConfiguration.CFDictionaryRef))
        self.assertTrue(isinstance(available, SystemConfiguration.CFArrayRef))

        r = SystemConfiguration.SCNetworkInterfaceCopyMediaSubTypes(available)
        self.assertTrue(isinstance(r, SystemConfiguration.CFArrayRef))
        for item in r:
            self.assertTrue(isinstance(item, str))

        r = SystemConfiguration.SCNetworkInterfaceCopyMediaSubTypeOptions(
            available, r[0]
        )
        self.assertTrue(isinstance(r, SystemConfiguration.CFArrayRef))

        r, mtu_cur, mtu_min, mtu_max = SystemConfiguration.SCNetworkInterfaceCopyMTU(
            iface, None, None, None
        )
        self.assertTrue(r is True)
        self.assertTrue(isinstance(mtu_cur, int))
        self.assertTrue(isinstance(mtu_min, int))
        self.assertTrue(isinstance(mtu_max, int))
        r = SystemConfiguration.SCNetworkInterfaceSetMediaOptions(
            iface, current["MediaSubType"], current["MediaOptions"]
        )
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCNetworkInterfaceSetMTU(iface, mtu_cur)
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCNetworkInterfaceForceConfigurationRefresh(iface)
        self.assertTrue(r is True or r is False)

        prefs = SystemConfiguration.SCPreferencesCreate(
            None, "SystemConfiguration", None
        )
        self.assertTrue(isinstance(prefs, SystemConfiguration.SCPreferencesRef))

        a = SystemConfiguration.SCBondInterfaceCopyAll(prefs)
        self.assertTrue(isinstance(a, SystemConfiguration.CFArrayRef))

        a = SystemConfiguration.SCBondInterfaceCopyAvailableMemberInterfaces(prefs)
        self.assertTrue(isinstance(a, SystemConfiguration.CFArrayRef))

        self.assertResultIsCFRetained(SystemConfiguration.SCBondInterfaceCreate)
        iface = SystemConfiguration.SCBondInterfaceCreate(prefs)
        self.assertTrue(
            iface is None or isinstance(iface, SystemConfiguration.SCBondInterfaceRef)
        )

        if iface is not None:
            a = SystemConfiguration.SCBondInterfaceGetMemberInterfaces(iface)
            self.assertTrue(isinstance(a, SystemConfiguration.CFArrayRef))

            o = SystemConfiguration.SCBondInterfaceGetOptions(iface)
            self.assertTrue(
                o is None or isinstance(o, SystemConfiguration.CFDictionaryRef)
            )

            r = SystemConfiguration.SCBondInterfaceSetMemberInterfaces(
                iface, SystemConfiguration.SCNetworkInterfaceCopyAll()
            )
            self.assertTrue(r is True or r is False)

            r = SystemConfiguration.SCBondInterfaceSetLocalizedDisplayName(
                iface, "pyobjc.bond"
            )
            self.assertTrue(r is True or r is False)

            r = SystemConfiguration.SCBondInterfaceSetOptions(iface, {})
            self.assertTrue(r is True or r is False)

            st = SystemConfiguration.SCBondInterfaceCopyStatus(iface)
            self.assertTrue(
                st is None or isinstance(st, SystemConfiguration.SCBondStatusRef)
            )

            a = SystemConfiguration.SCBondStatusGetMemberInterfaces(iface)
            self.assertTrue(a is None or isinstance(a, SystemConfiguration.CFArrayRef))

            st = SystemConfiguration.SCBondStatusGetInterfaceStatus(iface, None)
            self.assertTrue(
                a is None or isinstance(a, SystemConfiguration.CFDictionaryRef)
            )

            r = SystemConfiguration.SCBondInterfaceRemove(iface)
            self.assertTrue(r is True)

        r = SystemConfiguration.SCBondStatusGetTypeID()
        self.assertTrue(isinstance(r, int))

        a = SystemConfiguration.SCVLANInterfaceCopyAll(prefs)
        self.assertTrue(isinstance(a, SystemConfiguration.CFArrayRef))

        a = SystemConfiguration.SCVLANInterfaceCopyAvailablePhysicalInterfaces()
        self.assertTrue(isinstance(a, SystemConfiguration.CFArrayRef))

        if len(a) != 0:
            iface = SystemConfiguration.SCVLANInterfaceCreate(prefs, a[0], 99)
            self.assertTrue(isinstance(iface, SystemConfiguration.SCVLANInterfaceRef))

            r = SystemConfiguration.SCVLANInterfaceGetPhysicalInterface(iface)
            self.assertEqual(r, a[0])

            t = SystemConfiguration.SCVLANInterfaceGetTag(iface)
            self.assertEqual(t, 99)

            t = SystemConfiguration.SCVLANInterfaceGetOptions(iface)
            self.assertTrue(
                t is None or isinstance(t, SystemConfiguration.CFDictionaryRef)
            )

            r = SystemConfiguration.SCVLANInterfaceSetPhysicalInterfaceAndTag(
                iface, a[0], 42
            )
            self.assertIs(r, True)

            r = SystemConfiguration.SCVLANInterfaceSetLocalizedDisplayName(
                iface, "octest"
            )
            self.assertIs(r, True)

            r = SystemConfiguration.SCVLANInterfaceSetOptions(iface, {"name": "foo"})
            self.assertIs(r, True)

            t = SystemConfiguration.SCVLANInterfaceGetOptions(iface)
            self.assertIsInstance(t, (dict, SystemConfiguration.CFDictionaryRef))

            r = SystemConfiguration.SCVLANInterfaceRemove(iface)
            self.assertTrue(r is True)

        self.assertResultIsCFRetained(SystemConfiguration.SCVLANInterfaceCreate)
        SystemConfiguration.SCVLANInterfaceRemove
        SystemConfiguration.SCVLANInterfaceGetPhysicalInterface
        SystemConfiguration.SCVLANInterfaceGetTag
        SystemConfiguration.SCVLANInterfaceGetOptions
        SystemConfiguration.SCVLANInterfaceSetPhysicalInterfaceAndTag
        SystemConfiguration.SCVLANInterfaceSetLocalizedDisplayName
        SystemConfiguration.SCVLANInterfaceSetOptions

        r = SystemConfiguration.SCNetworkProtocolGetTypeID()
        self.assertTrue(isinstance(r, int))

        r = SystemConfiguration.SCNetworkServiceGetTypeID()
        self.assertTrue(isinstance(r, int))

        r = SystemConfiguration.SCNetworkSetGetTypeID()
        self.assertTrue(isinstance(r, int))

        r = SystemConfiguration.SCNetworkServiceCopyAll(prefs)
        self.assertIsInstance(r, SystemConfiguration.CFArrayRef)

        serv = r[0]
        self.assertIsInstance(serv, SystemConfiguration.SCNetworkServiceRef)
        prot = SystemConfiguration.SCNetworkServiceCopyProtocol(
            serv, SystemConfiguration.kSCNetworkProtocolTypeIPv4
        )
        self.assertIsInstance(prot, SystemConfiguration.SCNetworkProtocolRef)

        conf = SystemConfiguration.SCNetworkProtocolGetConfiguration(prot)
        self.assertIsInstance(conf, SystemConfiguration.CFDictionaryRef)

        enabled = SystemConfiguration.SCNetworkProtocolGetEnabled(prot)
        self.assertIsInstance(enabled, bool)

        pr = SystemConfiguration.SCNetworkProtocolGetProtocolType(prot)
        self.assertIsInstance(pr, str)

        v = SystemConfiguration.SCNetworkProtocolSetConfiguration(prot, conf)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkProtocolSetEnabled(prot, enabled)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkServiceAddProtocolType(serv, pr)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkServiceCopyProtocols(serv)
        self.assertIsInstance(v, SystemConfiguration.CFArrayRef)
        if v:
            self.assertIsInstance(v[0], SystemConfiguration.SCNetworkProtocolRef)

        iface = SystemConfiguration.SCNetworkServiceGetInterface(serv)
        self.assertIsInstance(iface, SystemConfiguration.SCNetworkInterfaceRef)

        v = SystemConfiguration.SCNetworkServiceCreate(prefs, iface)
        self.assertIsInstance(v, SystemConfiguration.SCNetworkServiceRef)

        v = s2 = SystemConfiguration.SCNetworkServiceCopy(
            prefs, SystemConfiguration.SCNetworkServiceGetServiceID(serv)
        )
        self.assertIsInstance(v, SystemConfiguration.SCNetworkServiceRef)

        v = SystemConfiguration.SCNetworkServiceGetEnabled(serv)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkServiceGetName(serv)
        self.assertIsInstance(v, str)

        self.assertResultIsCFRetained(SystemConfiguration.SCNetworkServiceCopyProtocol)

        v = SystemConfiguration.SCNetworkServiceRemoveProtocolType(
            s2, SystemConfiguration.kSCNetworkProtocolTypeIPv4
        )
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkServiceRemove(s2)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkServiceSetEnabled(
            serv, SystemConfiguration.SCNetworkServiceGetEnabled(serv)
        )
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkServiceSetName(
            serv, SystemConfiguration.SCNetworkServiceGetName(serv)
        )
        self.assertIsInstance(v, bool)

        a_set = SystemConfiguration.SCNetworkSetCopyCurrent(prefs)
        self.assertIsInstance(a_set, SystemConfiguration.SCNetworkSetRef)

        s2 = SystemConfiguration.SCNetworkServiceCopy(
            prefs, SystemConfiguration.SCNetworkServiceGetServiceID(serv)
        )

        v = SystemConfiguration.SCNetworkSetAddService(set, s2)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkSetContainsInterface(set, iface)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkSetCopyAll(prefs)
        self.assertIsInstance(v, SystemConfiguration.CFArrayRef)

        v = SystemConfiguration.SCNetworkSetCopyServices(a_set)
        self.assertIsInstance(v, SystemConfiguration.CFArrayRef)

        v = SystemConfiguration.SCNetworkSetCreate(prefs)
        self.assertIsInstance(v, SystemConfiguration.SCNetworkSetRef)

        v = SystemConfiguration.SCNetworkSetCopy(
            prefs, SystemConfiguration.SCNetworkSetGetSetID(a_set)
        )
        self.assertIsInstance(v, SystemConfiguration.SCNetworkSetRef)

        v = SystemConfiguration.SCNetworkSetRemove(v)
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkSetGetName(a_set)
        self.assertIsInstance(v, str)

        v = SystemConfiguration.SCNetworkSetGetSetID(a_set)
        self.assertIsInstance(v, str)

        v = SystemConfiguration.SCNetworkSetGetServiceOrder(a_set)
        self.assertIsInstance(v, SystemConfiguration.CFArrayRef)

        v = SystemConfiguration.SCNetworkSetSetName(
            a_set, SystemConfiguration.SCNetworkSetGetName(a_set)
        )
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkSetSetServiceOrder(
            a_set, SystemConfiguration.SCNetworkSetGetServiceOrder(a_set)
        )
        self.assertIsInstance(v, bool)

        v = SystemConfiguration.SCNetworkSetSetCurrent(
            SystemConfiguration.SCNetworkSetCopyCurrent(prefs)
        )
        self.assertIsInstance(v, bool)

        self.assertResultIsBOOL(SystemConfiguration.SCNetworkSetRemoveService)

    @min_os_level("10.5")
    def testFunctions10_5(self):
        prefs = SystemConfiguration.SCPreferencesCreate(
            None, "SystemConfiguration", None
        )
        self.assertTrue(isinstance(prefs, SystemConfiguration.SCPreferencesRef))

        r = SystemConfiguration.SCNetworkServiceCopyAll(prefs)
        self.assertIsInstance(r, SystemConfiguration.CFArrayRef)
        serv = SystemConfiguration.SCNetworkServiceCopy(
            prefs, SystemConfiguration.SCNetworkServiceGetServiceID(r[0])
        )

        v = SystemConfiguration.SCNetworkServiceEstablishDefaultConfiguration(serv)
        self.assertIsInstance(v, bool)



#!/usr/bin/env python
"""
Tells whether the internet is available using the SystemConfiguration
framework.

Usage:
    python internetison [address]
"""
import socket
import sys

from Cocoa import (
    CFRunLoopGetCurrent,
    CFRunLoopRun,
    CFRunLoopStop,
    kCFRunLoopCommonModes,
)
from SystemConfiguration import (
    SCNetworkReachabilityCreateWithAddress,
    SCNetworkReachabilityGetFlags,
    SCNetworkReachabilityScheduleWithRunLoop,
    SCNetworkReachabilitySetCallback,
    kSCNetworkFlagsConnectionAutomatic,
    kSCNetworkFlagsConnectionRequired,
    kSCNetworkFlagsInterventionRequired,
    kSCNetworkFlagsIsDirect,
    kSCNetworkFlagsIsLocalAddress,
    kSCNetworkFlagsReachable,
    kSCNetworkFlagsTransientConnection,
)


def resultAvailable(target, flags, info):
    print("got network reachability status for %s:" % (info,))

    if flags & kSCNetworkFlagsTransientConnection:
        print("- transient connection")

    if flags & kSCNetworkFlagsReachable:
        print("- reachable")

    if flags & kSCNetworkFlagsConnectionRequired:
        print("- connection required")

    if flags & kSCNetworkFlagsConnectionAutomatic:
        print("- connection automatic")

    if flags & kSCNetworkFlagsInterventionRequired:
        print("- user intervention required")

    if flags & kSCNetworkFlagsIsLocalAddress:
        print("- local interface")

    if flags & kSCNetworkFlagsIsDirect:
        print("- directly attached network")

    # And stop the program:
    loop = CFRunLoopGetCurrent()
    CFRunLoopStop(loop)


def main():
    if len(sys.argv) >= 2:
        addr = socket.gethostbyname(sys.argv[1])
    else:
        addr = "82.94.237.218"  # www.python.org

    loop = CFRunLoopGetCurrent()

    target = SCNetworkReachabilityCreateWithAddress(None, (addr, 80))
    SCNetworkReachabilitySetCallback(target, resultAvailable, addr)

    ok, flags = SCNetworkReachabilityGetFlags(target, None)
    if ok:
        resultAvailable(target, flags, addr)

    else:
        ok = SCNetworkReachabilityScheduleWithRunLoop(
            target, loop, kCFRunLoopCommonModes
        )

        CFRunLoopRun()


if __name__ == "__main__":
    main()



from PyObjCTools.TestSupport import TestCase
import objc
import SystemConfiguration


class TestDHCPClientPreferences(TestCase):
    def testFunctions(self):
        self.assertRaises(
            ValueError,
            SystemConfiguration.DHCPClientPreferencesSetApplicationOptions,
            "org.pyobjc.TestSuite",
            [9, 10, 0],
            4,
        )

        r = SystemConfiguration.DHCPClientPreferencesSetApplicationOptions(
            "org.pyobjc.TestSuite", [9, 10, 0, 9], 4
        )
        self.assertTrue(r is True or r is False)

        r, count = SystemConfiguration.DHCPClientPreferencesCopyApplicationOptions(
            "com.apple.SystemPreferences", None
        )
        self.assertTrue(r is objc.NULL)
        self.assertTrue(count == 0)



import socket

from PyObjCTools.TestSupport import TestCase, onlyIf
import SystemConfiguration
import objc


def resolver_available():
    try:
        socket.gethostbyname("www.python.org")
        return True
    except socket.error:
        return False


class TestSCNetwork(TestCase):
    def testConstants(self):
        self.assertEqual(SystemConfiguration.kSCNetworkFlagsTransientConnection, 1 << 0)
        self.assertEqual(SystemConfiguration.kSCNetworkFlagsReachable, 1 << 1)
        self.assertEqual(SystemConfiguration.kSCNetworkFlagsConnectionRequired, 1 << 2)
        self.assertEqual(SystemConfiguration.kSCNetworkFlagsConnectionAutomatic, 1 << 3)
        self.assertEqual(
            SystemConfiguration.kSCNetworkFlagsInterventionRequired, 1 << 4
        )
        self.assertEqual(SystemConfiguration.kSCNetworkFlagsIsLocalAddress, 1 << 16)
        self.assertEqual(SystemConfiguration.kSCNetworkFlagsIsDirect, 1 << 17)

    def testHardFunctionsNoHost(self):
        self.assertRaises(
            socket.gaierror,
            SystemConfiguration.SCNetworkCheckReachabilityByAddress,
            ("no-such-host.objective-python.org", 80),
            objc._size_sockaddr_ip4,
            None,
        )

    @onlyIf(resolver_available(), "No DNS resolver available")
    def testHardFunctions(self):
        b, flags = SystemConfiguration.SCNetworkCheckReachabilityByAddress(
            ("www.python.org", 80), objc._size_sockaddr_ip4, None
        )
        self.assertIsInstance(b, bool)
        self.assertIsInstance(flags, int)
        self.assertEqual(b, True)
        self.assertEqual(flags, SystemConfiguration.kSCNetworkFlagsReachable)

    @onlyIf(resolver_available(), "No DNS resolver available")
    def testFunctions(self):
        r, flags = SystemConfiguration.SCNetworkCheckReachabilityByName(
            b"www.python.org", None
        )
        self.assertTrue(r is True or r is False)
        self.assertTrue(isinstance(flags, int))

        r = SystemConfiguration.SCNetworkInterfaceRefreshConfiguration("en0")
        self.assertTrue(r is True or r is False)



import contextlib
import socket
import objc

from PyObjCTest.test_scnetwork import resolver_available
from PyObjCTools.TestSupport import TestCase, min_os_level, onlyIf
import SystemConfiguration


class TestSCNetworkReachability(TestCase):
    def testTypes(self):
        self.assertIsInstance(
            SystemConfiguration.SCNetworkReachabilityRef, objc.objc_class
        )

    @onlyIf(resolver_available(), "No DNS resolver available")
    def testFunctions(self):
        self.assertResultIsCFRetained(
            SystemConfiguration.SCNetworkReachabilityCreateWithAddressPair
        )
        v = SystemConfiguration.SCNetworkReachabilityCreateWithAddressPair(
            None, ("0.0.0.0", 20990), ("www.python.org", 80)
        )

        with contextlib.closing(
            socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        ) as sd:
            sd.listen(5)

            self.assertResultIsCFRetained(
                SystemConfiguration.SCNetworkReachabilityCreateWithAddress
            )
            ref = v = SystemConfiguration.SCNetworkReachabilityCreateWithAddress(
                None, sd.getsockname()
            )
            self.assertIsInstance(v, SystemConfiguration.SCNetworkReachabilityRef)

            self.assertResultIsCFRetained(
                SystemConfiguration.SCNetworkReachabilityCreateWithName
            )
            v = SystemConfiguration.SCNetworkReachabilityCreateWithName(
                None, b"www.python.org"
            )
            self.assertIsInstance(v, SystemConfiguration.SCNetworkReachabilityRef)

            v = SystemConfiguration.SCNetworkReachabilityGetTypeID()
            self.assertIsInstance(v, int)

            self.assertResultIsBOOL(SystemConfiguration.SCNetworkReachabilityGetFlags)
            v, fl = SystemConfiguration.SCNetworkReachabilityGetFlags(ref, None)
            self.assertTrue(v)
            self.assertIsInstance(fl, int)

            lst = []

            def callout(ref, flags, ctx):
                lst.append([ref, flags, ctx])

            ctx = object()
            v = SystemConfiguration.SCNetworkReachabilitySetCallback(ref, callout, ctx)
            self.assertTrue(v is True)

            rl = SystemConfiguration.CFRunLoopGetCurrent()
            self.assertResultIsBOOL(
                SystemConfiguration.SCNetworkReachabilityScheduleWithRunLoop
            )
            SystemConfiguration.SCNetworkReachabilityScheduleWithRunLoop(
                ref, rl, SystemConfiguration.kCFRunLoopCommonModes
            )

            SystemConfiguration.CFRunLoopRunInMode(
                SystemConfiguration.kCFRunLoopDefaultMode, 1.0, False
            )

            self.assertResultIsBOOL(
                SystemConfiguration.SCNetworkReachabilityUnscheduleFromRunLoop
            )
            SystemConfiguration.SCNetworkReachabilityUnscheduleFromRunLoop(
                ref, rl, SystemConfiguration.kCFRunLoopCommonModes
            )

        @min_os_level("10.6")
        def testFunctions10_6(self):
            self.assertResultIsBOOL(
                SystemConfiguration.SCNetworkReachabilitySetDispatchQueue
            )

        def testConstants(self):
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsTransientConnection,
                1 << 0,
            )
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsReachable, 1 << 1
            )
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsConnectionRequired,
                1 << 2,
            )
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsConnectionOnTraffic,
                1 << 3,
            )
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsInterventionRequired,
                1 << 4,
            )
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsConnectionOnDemand,
                1 << 5,
            )
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsIsLocalAddress, 1 << 16
            )
            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsIsDirect, 1 << 17
            )

            self.assertEqual(
                SystemConfiguration.kSCNetworkReachabilityFlagsConnectionAutomatic,
                SystemConfiguration.kSCNetworkReachabilityFlagsConnectionOnTraffic,
            )



#!/usr/bin/env
"""
This is a simple tool that exercises the some callback functions in the
SystemConfiguration framework.

In an ideal world this would be a nice GUI.

Usage:
    python callbacks.py
"""
from __future__ import print_function

import signal

from Cocoa import (
    CFRunLoopAddSource,
    CFRunLoopGetCurrent,
    CFRunLoopRun,
    CFRunLoopStop,
    kCFRunLoopCommonModes,
)
from SystemConfiguration import (
    SCDynamicStoreCreate,
    SCDynamicStoreCreateRunLoopSource,
    SCDynamicStoreSetNotificationKeys,
    SCPreferencesCreate,
    SCPreferencesScheduleWithRunLoop,
    SCPreferencesSetCallback,
)


def sigint(*args):
    print("SIGINT: bailing out")
    loop = CFRunLoopGetCurrent()
    CFRunLoopStop(loop)


def dynamicStoreChanged(store, changedKeys, info):
    print("Dynamic Store: keys changed", changedKeys)


def prefsChanged(prefs, notificationType, info):
    print("Prefs changed, type:", notificationType)


def main():
    # Setup a dynamic store controller that monitors all keys:
    store = SCDynamicStoreCreate(None, "demo.controller", dynamicStoreChanged, None)
    SCDynamicStoreSetNotificationKeys(store, None, [".*"])
    source = SCDynamicStoreCreateRunLoopSource(None, store, 0)

    # Setup a preferences controller
    prefs = SCPreferencesCreate(None, "demo.prefs", None)
    SCPreferencesSetCallback(prefs, prefsChanged, None)

    # Set up a run loop and add all controllers to that.
    loop = CFRunLoopGetCurrent()
    CFRunLoopAddSource(loop, source, kCFRunLoopCommonModes)
    SCPreferencesScheduleWithRunLoop(prefs, loop, kCFRunLoopCommonModes)

    signal.signal(signal.SIGINT, sigint)
    CFRunLoopRun()


if __name__ == "__main__":
    main()



import os

from Foundation import NSDate
from PyObjCTools.TestSupport import TestCase
import SystemConfiguration


class TestSCDynamicStoreCopyDHCPInfo(TestCase):
    def testFunctions(self):
        def callback(st, keys, info):
            pass

        st = SystemConfiguration.SCDynamicStoreCreate(
            None, "pyobjc.test", callback, None
        )
        self.assertTrue(isinstance(st, SystemConfiguration.SCDynamicStoreRef))

        have_ip = False
        with os.popen("ifconfig en0 | grep inet", "r") as fp:
            ip = fp.read()
        if ip.strip():
            have_ip = True
        else:
            with os.popen("ifconfig en1 | grep inet", "r") as fp:
                ip = fp.read()
            if ip.strip():
                have_ip = True

        info = SystemConfiguration.SCDynamicStoreCopyDHCPInfo(st, None)
        if not have_ip:
            self.assertIs(info, None)
        else:
            self.assertIsInstance(info, SystemConfiguration.CFDictionaryRef)

            r = SystemConfiguration.DHCPInfoGetOptionData(info, 1)
            self.assertTrue(r is None or isinstance(r, SystemConfiguration.NSData))

            r = SystemConfiguration.DHCPInfoGetLeaseStartTime(info)
            self.assertTrue(r is None or isinstance(r, SystemConfiguration.NSDate))

        SystemConfiguration.DHCPInfoGetLeaseExpirationTime

        if info:
            r = SystemConfiguration.DHCPInfoGetLeaseExpirationTime(info)
            self.assertTrue(r is None or isinstance(r, NSDate))



"""
Python mapping for the SystemConfiguration framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""
import sys

import Foundation
import objc
from SystemConfiguration import _metadata

sys.modules["SystemConfiguration"] = mod = objc.ObjCLazyModule(
    "SystemConfiguration",
    "com.apple.SystemConfiguration",
    objc.pathForFramework("/System/Library/Frameworks/SystemConfiguration.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
        "objc": objc,
    },
    (Foundation,),
)


del sys.modules["SystemConfiguration._metadata"]


import SystemConfiguration._manual as m  # isort:skip  # noqa: E402

for nm in dir(m):
    setattr(mod, nm, getattr(m, nm))

mod.SCBondInterfaceRef = mod.SCNetworkInterfaceRef
mod.SCVLANInterfaceRef = mod.SCNetworkInterfaceRef



from PyObjCTools.TestSupport import TestCase
import SystemConfiguration


class TestSCPreferencesSetSpecific(TestCase):
    def testFunctions(self):
        ref = SystemConfiguration.SCPreferencesCreate(
            None, "pyobjc.test", "pyobjc.test"
        )
        self.assertIsInstance(ref, SystemConfiguration.SCPreferencesRef)

        v = SystemConfiguration.SCPreferencesSetComputerName(
            ref, "my host", SystemConfiguration.kCFStringEncodingUTF8
        )
        self.assertTrue(isinstance(v, bool))

        v = SystemConfiguration.SCPreferencesSetLocalHostName(ref, "my.host.private")
        self.assertTrue(isinstance(v, bool))

        # NOTE: Do not commit changes, that would mess with the computer running
        # the tests



import os

from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure
import SystemConfiguration
import objc


class TestSCDynamicStore(TestCase):
    def testTypes(self):
        self.assertTrue(
            isinstance(SystemConfiguration.SCDynamicStoreRef, objc.objc_class)
        )

    def testStructs(self):
        self.assertFalse(hasattr(SystemConfiguration, "SCDynamicStoreContext"))

    def testFunctions(self):
        n = SystemConfiguration.SCDynamicStoreGetTypeID()
        self.assertTrue(isinstance(n, int))

        lst = []
        info = object()

        def callback(store, changedKeys, info):
            lst.append((store, changedKeys, info))

        st = SystemConfiguration.SCDynamicStoreCreate(
            None, "pyobjc.test", callback, info
        )
        self.assertTrue(isinstance(st, SystemConfiguration.SCDynamicStoreRef))

        st = SystemConfiguration.SCDynamicStoreCreateWithOptions(
            None, "pyobjc.test", {}, callback, info
        )
        self.assertTrue(isinstance(st, SystemConfiguration.SCDynamicStoreRef))

        src = SystemConfiguration.SCDynamicStoreCreateRunLoopSource(None, st, 0)
        self.assertTrue(isinstance(src, SystemConfiguration.CFRunLoopSourceRef))
        del src

        v = SystemConfiguration.SCDynamicStoreCopyKeyList(st, ".*")
        self.assertTrue(isinstance(v, SystemConfiguration.CFArrayRef))
        self.assertTrue(len(v) > 0)
        self.assertTrue(isinstance(v[0], str))

        r = SystemConfiguration.SCDynamicStoreAddValue(st, "Setup:/PyObjC", {"key": 42})
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCDynamicStoreAddTemporaryValue(
            st, "Setup:/PyObjC", {"key": 42}
        )
        self.assertTrue(r is True or r is False)

        v = SystemConfiguration.SCDynamicStoreCopyValue(st, "Setup:/")
        self.assertTrue(isinstance(v, SystemConfiguration.CFDictionaryRef))

        v = SystemConfiguration.SCDynamicStoreCopyMultiple(st, None, [".*"])
        self.assertTrue(isinstance(v, SystemConfiguration.CFDictionaryRef))

        r = SystemConfiguration.SCDynamicStoreSetValue(st, "Setup:/PyObjC", {"key": 42})
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCDynamicStoreSetMultiple(
            st, {"Setup:/PyObjC2": {"key": 42}}, ["Setup:/PyObjC"], ["System:/"]
        )
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCDynamicStoreRemoveValue(st, "Setup:/PyObjC")
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCDynamicStoreNotifyValue(st, "Setup:/")
        self.assertTrue(r is True or r is False)

        r = SystemConfiguration.SCDynamicStoreSetNotificationKeys(st, ["Setup:/"], None)
        self.assertTrue(r is True)

        r = SystemConfiguration.SCDynamicStoreCopyNotifiedKeys(st)
        self.assertTrue(isinstance(r, SystemConfiguration.CFArrayRef))

    @expectedFailure
    def testCallbacks(self):
        if os.getuid() != 0:
            self.fail("WARNING: Need root privileges to test callback mechanism")
            return

        info = object()
        lst = []

        def callback(store, changedKeys, info):
            lst.append((store, changedKeys, info))

        st = SystemConfiguration.SCDynamicStoreCreate(
            None, b"pyobjc.test", callback, info
        )

        SystemConfiguration.SCDynamicStoreSetNotificationKeys(st, None, [".*"])
        src = SystemConfiguration.SCDynamicStoreCreateRunLoopSource(None, st, 0)
        self.assertTrue(isinstance(src, SystemConfiguration.CFRunLoopSourceRef))

        SystemConfiguration.SCDynamicStoreAddTemporaryValue(
            st, "pyobjc.test.key", "value"
        )

        SystemConfiguration.CFRunLoopAddSource(
            SystemConfiguration.CFRunLoopGetCurrent(),
            src,
            SystemConfiguration.kCFRunLoopCommonModes,
        )
        SystemConfiguration.CFRunLoopRunInMode(
            SystemConfiguration.kCFRunLoopDefaultMode, 2.0, False
        )

        self.assertTrue(len(lst) > 1)
        self.assertTrue(lst[0][0] is st)
        self.assertIsInstance(lst[0][1], SystemConfiguration.CFArrayRef)
        self.assertTrue(lst[0][2] is info)

    @min_os_level("10.6")
    def testFunctions10_6(self):
        self.assertResultIsBOOL(SystemConfiguration.SCDynamicStoreSetDispatchQueue)

    def testContants(self):
        self.assertTrue(
            isinstance(SystemConfiguration.kSCDynamicStoreUseSessionKeys, str)
        )



import SystemConfiguration
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCaptiveNework(TestCase):
    @min_os_level("10.8")
    def testFunctions10_8(self):
        self.assertResultIsBOOL(SystemConfiguration.CNSetSupportedSSIDs)
        self.assertResultIsBOOL(SystemConfiguration.CNMarkPortalOnline)
        self.assertResultIsBOOL(SystemConfiguration.CNMarkPortalOffline)
        self.assertResultIsCFRetained(SystemConfiguration.CNCopySupportedInterfaces)



from PyObjCTools.TestSupport import TestCase
import SystemConfiguration


class TestSCDynamicStoreCopySpecific(TestCase):
    def testFunctions(self):
        def callback(st, keys, info):
            pass

        st = SystemConfiguration.SCDynamicStoreCreate(
            None, "pyobjc.test", callback, None
        )
        self.assertTrue(isinstance(st, SystemConfiguration.SCDynamicStoreRef))

        nm, encoding = SystemConfiguration.SCDynamicStoreCopyComputerName(st, None)
        self.assertTrue(isinstance(nm, str))
        self.assertTrue(isinstance(encoding, int))

        nm, uid, gid = SystemConfiguration.SCDynamicStoreCopyConsoleUser(st, None, None)
        self.assertTrue(isinstance(nm, str))
        self.assertTrue(isinstance(uid, int))
        self.assertTrue(isinstance(gid, int))

        nm = SystemConfiguration.SCDynamicStoreCopyLocalHostName(st)
        self.assertTrue(isinstance(nm, str))

        nm = SystemConfiguration.SCDynamicStoreCopyLocation(st)
        self.assertTrue(isinstance(nm, str))

        r = SystemConfiguration.SCDynamicStoreCopyProxies(st)
        self.assertTrue(r is None or isinstance(r, SystemConfiguration.CFDictionaryRef))



# This file is generated by objective.metadata
#
# Last update: Sun Jun 28 11:16:58 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$kCFErrorDomainSystemConfiguration@^{__CFString=}$kCNNetworkInfoKeyBSSID@^{__CFString=}$kCNNetworkInfoKeySSID@^{__CFString=}$kCNNetworkInfoKeySSIDData@^{__CFString=}$kSCBondStatusDeviceAggregationStatus@^{__CFString=}$kSCBondStatusDeviceCollecting@^{__CFString=}$kSCBondStatusDeviceDistributing@^{__CFString=}$kSCCompAnyRegex@^{__CFString=}$kSCCompGlobal@^{__CFString=}$kSCCompHostNames@^{__CFString=}$kSCCompInterface@^{__CFString=}$kSCCompNetwork@^{__CFString=}$kSCCompService@^{__CFString=}$kSCCompSystem@^{__CFString=}$kSCCompUsers@^{__CFString=}$kSCDynamicStoreDomainFile@^{__CFString=}$kSCDynamicStoreDomainPlugin@^{__CFString=}$kSCDynamicStoreDomainPrefs@^{__CFString=}$kSCDynamicStoreDomainSetup@^{__CFString=}$kSCDynamicStoreDomainState@^{__CFString=}$kSCDynamicStorePropNetInterfaces@^{__CFString=}$kSCDynamicStorePropNetPrimaryInterface@^{__CFString=}$kSCDynamicStorePropNetPrimaryService@^{__CFString=}$kSCDynamicStorePropNetServiceIDs@^{__CFString=}$kSCDynamicStorePropSetupCurrentSet@^{__CFString=}$kSCDynamicStorePropSetupLastUpdated@^{__CFString=}$kSCDynamicStoreUseSessionKeys@^{__CFString=}$kSCEntNet6to4@^{__CFString=}$kSCEntNetAirPort@^{__CFString=}$kSCEntNetAppleTalk@^{__CFString=}$kSCEntNetDHCP@^{__CFString=}$kSCEntNetDNS@^{__CFString=}$kSCEntNetEthernet@^{__CFString=}$kSCEntNetFireWire@^{__CFString=}$kSCEntNetIPSec@^{__CFString=}$kSCEntNetIPv4@^{__CFString=}$kSCEntNetIPv6@^{__CFString=}$kSCEntNetInterface@^{__CFString=}$kSCEntNetL2TP@^{__CFString=}$kSCEntNetLink@^{__CFString=}$kSCEntNetModem@^{__CFString=}$kSCEntNetNetInfo@^{__CFString=}$kSCEntNetPPP@^{__CFString=}$kSCEntNetPPPSerial@^{__CFString=}$kSCEntNetPPPoE@^{__CFString=}$kSCEntNetPPTP@^{__CFString=}$kSCEntNetProxies@^{__CFString=}$kSCEntNetSMB@^{__CFString=}$kSCEntUsersConsoleUser@^{__CFString=}$kSCNetworkInterfaceIPv4@=^{__SCNetworkInterface=}$kSCNetworkInterfaceType6to4@^{__CFString=}$kSCNetworkInterfaceTypeBluetooth@^{__CFString=}$kSCNetworkInterfaceTypeBond@^{__CFString=}$kSCNetworkInterfaceTypeEthernet@^{__CFString=}$kSCNetworkInterfaceTypeFireWire@^{__CFString=}$kSCNetworkInterfaceTypeIEEE80211@^{__CFString=}$kSCNetworkInterfaceTypeIPSec@^{__CFString=}$kSCNetworkInterfaceTypeIPv4@^{__CFString=}$kSCNetworkInterfaceTypeIrDA@^{__CFString=}$kSCNetworkInterfaceTypeL2TP@^{__CFString=}$kSCNetworkInterfaceTypeModem@^{__CFString=}$kSCNetworkInterfaceTypePPP@^{__CFString=}$kSCNetworkInterfaceTypePPTP@^{__CFString=}$kSCNetworkInterfaceTypeSerial@^{__CFString=}$kSCNetworkInterfaceTypeVLAN@^{__CFString=}$kSCNetworkInterfaceTypeWWAN@^{__CFString=}$kSCNetworkProtocolTypeAppleTalk@^{__CFString=}$kSCNetworkProtocolTypeDNS@^{__CFString=}$kSCNetworkProtocolTypeIPv4@^{__CFString=}$kSCNetworkProtocolTypeIPv6@^{__CFString=}$kSCNetworkProtocolTypeProxies@^{__CFString=}$kSCNetworkProtocolTypeSMB@^{__CFString=}$kSCPrefCurrentSet@^{__CFString=}$kSCPrefNetworkServices@^{__CFString=}$kSCPrefSets@^{__CFString=}$kSCPrefSystem@^{__CFString=}$kSCPropInterfaceName@^{__CFString=}$kSCPropMACAddress@^{__CFString=}$kSCPropNet6to4Relay@^{__CFString=}$kSCPropNetAirPortAllowNetCreation@^{__CFString=}$kSCPropNetAirPortAuthPassword@^{__CFString=}$kSCPropNetAirPortAuthPasswordEncryption@^{__CFString=}$kSCPropNetAirPortJoinMode@^{__CFString=}$kSCPropNetAirPortPowerEnabled@^{__CFString=}$kSCPropNetAirPortPreferredNetwork@^{__CFString=}$kSCPropNetAirPortSavePasswords@^{__CFString=}$kSCPropNetAppleTalkComputerName@^{__CFString=}$kSCPropNetAppleTalkComputerNameEncoding@^{__CFString=}$kSCPropNetAppleTalkConfigMethod@^{__CFString=}$kSCPropNetAppleTalkDefaultZone@^{__CFString=}$kSCPropNetAppleTalkNetworkID@^{__CFString=}$kSCPropNetAppleTalkNetworkRange@^{__CFString=}$kSCPropNetAppleTalkNodeID@^{__CFString=}$kSCPropNetAppleTalkSeedNetworkRange@^{__CFString=}$kSCPropNetAppleTalkSeedZones@^{__CFString=}$kSCPropNetDNSDomainName@^{__CFString=}$kSCPropNetDNSOptions@^{__CFString=}$kSCPropNetDNSSearchDomains@^{__CFString=}$kSCPropNetDNSSearchOrder@^{__CFString=}$kSCPropNetDNSServerAddresses@^{__CFString=}$kSCPropNetDNSServerPort@^{__CFString=}$kSCPropNetDNSServerTimeout@^{__CFString=}$kSCPropNetDNSSortList@^{__CFString=}$kSCPropNetDNSSupplementalMatchDomains@^{__CFString=}$kSCPropNetDNSSupplementalMatchOrders@^{__CFString=}$kSCPropNetEthernetMTU@^{__CFString=}$kSCPropNetEthernetMediaOptions@^{__CFString=}$kSCPropNetEthernetMediaSubType@^{__CFString=}$kSCPropNetIPSecAuthenticationMethod@^{__CFString=}$kSCPropNetIPSecConnectTime@^{__CFString=}$kSCPropNetIPSecLocalCertificate@^{__CFString=}$kSCPropNetIPSecLocalIdentifier@^{__CFString=}$kSCPropNetIPSecLocalIdentifierType@^{__CFString=}$kSCPropNetIPSecRemoteAddress@^{__CFString=}$kSCPropNetIPSecSharedSecret@^{__CFString=}$kSCPropNetIPSecSharedSecretEncryption@^{__CFString=}$kSCPropNetIPSecStatus@^{__CFString=}$kSCPropNetIPSecXAuthEnabled@^{__CFString=}$kSCPropNetIPSecXAuthName@^{__CFString=}$kSCPropNetIPSecXAuthPassword@^{__CFString=}$kSCPropNetIPSecXAuthPasswordEncryption@^{__CFString=}$kSCPropNetIPv4Addresses@^{__CFString=}$kSCPropNetIPv4BroadcastAddresses@^{__CFString=}$kSCPropNetIPv4ConfigMethod@^{__CFString=}$kSCPropNetIPv4DHCPClientID@^{__CFString=}$kSCPropNetIPv4DestAddresses@^{__CFString=}$kSCPropNetIPv4Router@^{__CFString=}$kSCPropNetIPv4SubnetMasks@^{__CFString=}$kSCPropNetIPv6Addresses@^{__CFString=}$kSCPropNetIPv6ConfigMethod@^{__CFString=}$kSCPropNetIPv6DestAddresses@^{__CFString=}$kSCPropNetIPv6Flags@^{__CFString=}$kSCPropNetIPv6PrefixLength@^{__CFString=}$kSCPropNetIPv6Router@^{__CFString=}$kSCPropNetInterfaceDeviceName@^{__CFString=}$kSCPropNetInterfaceHardware@^{__CFString=}$kSCPropNetInterfaceSubType@^{__CFString=}$kSCPropNetInterfaceSupportsModemOnHold@^{__CFString=}$kSCPropNetInterfaceType@^{__CFString=}$kSCPropNetInterfaces@^{__CFString=}$kSCPropNetL2TPIPSecSharedSecret@^{__CFString=}$kSCPropNetL2TPIPSecSharedSecretEncryption@^{__CFString=}$kSCPropNetL2TPTransport@^{__CFString=}$kSCPropNetLinkActive@^{__CFString=}$kSCPropNetLinkDetaching@^{__CFString=}$kSCPropNetLocalHostName@^{__CFString=}$kSCPropNetModemAccessPointName@^{__CFString=}$kSCPropNetModemConnectSpeed@^{__CFString=}$kSCPropNetModemConnectionPersonality@^{__CFString=}$kSCPropNetModemConnectionScript@^{__CFString=}$kSCPropNetModemDataCompression@^{__CFString=}$kSCPropNetModemDeviceContextID@^{__CFString=}$kSCPropNetModemDeviceModel@^{__CFString=}$kSCPropNetModemDeviceVendor@^{__CFString=}$kSCPropNetModemDialMode@^{__CFString=}$kSCPropNetModemErrorCorrection@^{__CFString=}$kSCPropNetModemHoldCallWaitingAudibleAlert@^{__CFString=}$kSCPropNetModemHoldDisconnectOnAnswer@^{__CFString=}$kSCPropNetModemHoldEnabled@^{__CFString=}$kSCPropNetModemHoldReminder@^{__CFString=}$kSCPropNetModemHoldReminderTime@^{__CFString=}$kSCPropNetModemNote@^{__CFString=}$kSCPropNetModemPulseDial@^{__CFString=}$kSCPropNetModemSpeaker@^{__CFString=}$kSCPropNetModemSpeed@^{__CFString=}$kSCPropNetNetInfoBindingMethods@^{__CFString=}$kSCPropNetNetInfoBroadcastServerTag@^{__CFString=}$kSCPropNetNetInfoServerAddresses@^{__CFString=}$kSCPropNetNetInfoServerTags@^{__CFString=}$kSCPropNetOverridePrimary@^{__CFString=}$kSCPropNetPPPACSPEnabled@^{__CFString=}$kSCPropNetPPPAuthEAPPlugins@^{__CFString=}$kSCPropNetPPPAuthName@^{__CFString=}$kSCPropNetPPPAuthPassword@^{__CFString=}$kSCPropNetPPPAuthPasswordEncryption@^{__CFString=}$kSCPropNetPPPAuthPrompt@^{__CFString=}$kSCPropNetPPPAuthProtocol@^{__CFString=}$kSCPropNetPPPCCPEnabled@^{__CFString=}$kSCPropNetPPPCCPMPPE128Enabled@^{__CFString=}$kSCPropNetPPPCCPMPPE40Enabled@^{__CFString=}$kSCPropNetPPPCommAlternateRemoteAddress@^{__CFString=}$kSCPropNetPPPCommConnectDelay@^{__CFString=}$kSCPropNetPPPCommDisplayTerminalWindow@^{__CFString=}$kSCPropNetPPPCommRedialCount@^{__CFString=}$kSCPropNetPPPCommRedialEnabled@^{__CFString=}$kSCPropNetPPPCommRedialInterval@^{__CFString=}$kSCPropNetPPPCommRemoteAddress@^{__CFString=}$kSCPropNetPPPCommTerminalScript@^{__CFString=}$kSCPropNetPPPCommUseTerminalScript@^{__CFString=}$kSCPropNetPPPConnectTime@^{__CFString=}$kSCPropNetPPPDeviceLastCause@^{__CFString=}$kSCPropNetPPPDialOnDemand@^{__CFString=}$kSCPropNetPPPDisconnectOnFastUserSwitch@^{__CFString=}$kSCPropNetPPPDisconnectOnIdle@^{__CFString=}$kSCPropNetPPPDisconnectOnIdleTimer@^{__CFString=}$kSCPropNetPPPDisconnectOnLogout@^{__CFString=}$kSCPropNetPPPDisconnectOnSleep@^{__CFString=}$kSCPropNetPPPDisconnectTime@^{__CFString=}$kSCPropNetPPPIPCPCompressionVJ@^{__CFString=}$kSCPropNetPPPIPCPUsePeerDNS@^{__CFString=}$kSCPropNetPPPIdleReminder@^{__CFString=}$kSCPropNetPPPIdleReminderTimer@^{__CFString=}$kSCPropNetPPPLCPCompressionACField@^{__CFString=}$kSCPropNetPPPLCPCompressionPField@^{__CFString=}$kSCPropNetPPPLCPEchoEnabled@^{__CFString=}$kSCPropNetPPPLCPEchoFailure@^{__CFString=}$kSCPropNetPPPLCPEchoInterval@^{__CFString=}$kSCPropNetPPPLCPMRU@^{__CFString=}$kSCPropNetPPPLCPMTU@^{__CFString=}$kSCPropNetPPPLCPReceiveACCM@^{__CFString=}$kSCPropNetPPPLCPTransmitACCM@^{__CFString=}$kSCPropNetPPPLastCause@^{__CFString=}$kSCPropNetPPPLogfile@^{__CFString=}$kSCPropNetPPPOverridePrimary@^{__CFString=}$kSCPropNetPPPPlugins@^{__CFString=}$kSCPropNetPPPRetryConnectTime@^{__CFString=}$kSCPropNetPPPSessionTimer@^{__CFString=}$kSCPropNetPPPStatus@^{__CFString=}$kSCPropNetPPPUseSessionTimer@^{__CFString=}$kSCPropNetPPPVerboseLogging@^{__CFString=}$kSCPropNetProxiesExceptionsList@^{__CFString=}$kSCPropNetProxiesExcludeSimpleHostnames@^{__CFString=}$kSCPropNetProxiesFTPEnable@^{__CFString=}$kSCPropNetProxiesFTPPassive@^{__CFString=}$kSCPropNetProxiesFTPPort@^{__CFString=}$kSCPropNetProxiesFTPProxy@^{__CFString=}$kSCPropNetProxiesGopherEnable@^{__CFString=}$kSCPropNetProxiesGopherPort@^{__CFString=}$kSCPropNetProxiesGopherProxy@^{__CFString=}$kSCPropNetProxiesHTTPEnable@^{__CFString=}$kSCPropNetProxiesHTTPPort@^{__CFString=}$kSCPropNetProxiesHTTPProxy@^{__CFString=}$kSCPropNetProxiesHTTPSEnable@^{__CFString=}$kSCPropNetProxiesHTTPSPort@^{__CFString=}$kSCPropNetProxiesHTTPSProxy@^{__CFString=}$kSCPropNetProxiesProxyAutoConfigEnable@^{__CFString=}$kSCPropNetProxiesProxyAutoConfigJavaScript@^{__CFString=}$kSCPropNetProxiesProxyAutoConfigURLString@^{__CFString=}$kSCPropNetProxiesProxyAutoDiscoveryEnable@^{__CFString=}$kSCPropNetProxiesRTSPEnable@^{__CFString=}$kSCPropNetProxiesRTSPPort@^{__CFString=}$kSCPropNetProxiesRTSPProxy@^{__CFString=}$kSCPropNetProxiesSOCKSEnable@^{__CFString=}$kSCPropNetProxiesSOCKSPort@^{__CFString=}$kSCPropNetProxiesSOCKSProxy@^{__CFString=}$kSCPropNetSMBNetBIOSName@^{__CFString=}$kSCPropNetSMBNetBIOSNodeType@^{__CFString=}$kSCPropNetSMBNetBIOSScope@^{__CFString=}$kSCPropNetSMBWINSAddresses@^{__CFString=}$kSCPropNetSMBWorkgroup@^{__CFString=}$kSCPropNetServiceOrder@^{__CFString=}$kSCPropSystemComputerName@^{__CFString=}$kSCPropSystemComputerNameEncoding@^{__CFString=}$kSCPropUserDefinedName@^{__CFString=}$kSCPropUsersConsoleUserGID@^{__CFString=}$kSCPropUsersConsoleUserName@^{__CFString=}$kSCPropUsersConsoleUserUID@^{__CFString=}$kSCPropVersion@^{__CFString=}$kSCResvInactive@^{__CFString=}$kSCResvLink@^{__CFString=}$kSCValNetAirPortAuthPasswordEncryptionKeychain@^{__CFString=}$kSCValNetAirPortJoinModeAutomatic@^{__CFString=}$kSCValNetAirPortJoinModePreferred@^{__CFString=}$kSCValNetAirPortJoinModeRanked@^{__CFString=}$kSCValNetAirPortJoinModeRecent@^{__CFString=}$kSCValNetAirPortJoinModeStrongest@^{__CFString=}$kSCValNetAppleTalkConfigMethodNode@^{__CFString=}$kSCValNetAppleTalkConfigMethodRouter@^{__CFString=}$kSCValNetAppleTalkConfigMethodSeedRouter@^{__CFString=}$kSCValNetIPSecAuthenticationMethodCertificate@^{__CFString=}$kSCValNetIPSecAuthenticationMethodHybrid@^{__CFString=}$kSCValNetIPSecAuthenticationMethodSharedSecret@^{__CFString=}$kSCValNetIPSecLocalIdentifierTypeKeyID@^{__CFString=}$kSCValNetIPSecSharedSecretEncryptionKeychain@^{__CFString=}$kSCValNetIPSecXAuthPasswordEncryptionKeychain@^{__CFString=}$kSCValNetIPSecXAuthPasswordEncryptionPrompt@^{__CFString=}$kSCValNetIPv4ConfigMethodAutomatic@^{__CFString=}$kSCValNetIPv4ConfigMethodBOOTP@^{__CFString=}$kSCValNetIPv4ConfigMethodDHCP@^{__CFString=}$kSCValNetIPv4ConfigMethodINFORM@^{__CFString=}$kSCValNetIPv4ConfigMethodLinkLocal@^{__CFString=}$kSCValNetIPv4ConfigMethodManual@^{__CFString=}$kSCValNetIPv4ConfigMethodPPP@^{__CFString=}$kSCValNetIPv6ConfigMethod6to4@^{__CFString=}$kSCValNetIPv6ConfigMethodAutomatic@^{__CFString=}$kSCValNetIPv6ConfigMethodLinkLocal@^{__CFString=}$kSCValNetIPv6ConfigMethodManual@^{__CFString=}$kSCValNetIPv6ConfigMethodRouterAdvertisement@^{__CFString=}$kSCValNetInterfaceSubTypeL2TP@^{__CFString=}$kSCValNetInterfaceSubTypePPPSerial@^{__CFString=}$kSCValNetInterfaceSubTypePPPoE@^{__CFString=}$kSCValNetInterfaceSubTypePPTP@^{__CFString=}$kSCValNetInterfaceType6to4@^{__CFString=}$kSCValNetInterfaceTypeEthernet@^{__CFString=}$kSCValNetInterfaceTypeFireWire@^{__CFString=}$kSCValNetInterfaceTypeIPSec@^{__CFString=}$kSCValNetInterfaceTypePPP@^{__CFString=}$kSCValNetL2TPIPSecSharedSecretEncryptionKeychain@^{__CFString=}$kSCValNetL2TPTransportIP@^{__CFString=}$kSCValNetL2TPTransportIPSec@^{__CFString=}$kSCValNetModemDialModeIgnoreDialTone@^{__CFString=}$kSCValNetModemDialModeManual@^{__CFString=}$kSCValNetModemDialModeWaitForDialTone@^{__CFString=}$kSCValNetNetInfoBindingMethodsBroadcast@^{__CFString=}$kSCValNetNetInfoBindingMethodsDHCP@^{__CFString=}$kSCValNetNetInfoBindingMethodsManual@^{__CFString=}$kSCValNetNetInfoDefaultServerTag@^{__CFString=}$kSCValNetPPPAuthPasswordEncryptionKeychain@^{__CFString=}$kSCValNetPPPAuthPasswordEncryptionToken@^{__CFString=}$kSCValNetPPPAuthPromptAfter@^{__CFString=}$kSCValNetPPPAuthPromptBefore@^{__CFString=}$kSCValNetPPPAuthProtocolCHAP@^{__CFString=}$kSCValNetPPPAuthProtocolEAP@^{__CFString=}$kSCValNetPPPAuthProtocolMSCHAP1@^{__CFString=}$kSCValNetPPPAuthProtocolMSCHAP2@^{__CFString=}$kSCValNetPPPAuthProtocolPAP@^{__CFString=}$kSCValNetSMBNetBIOSNodeTypeBroadcast@^{__CFString=}$kSCValNetSMBNetBIOSNodeTypeHybrid@^{__CFString=}$kSCValNetSMBNetBIOSNodeTypeMixed@^{__CFString=}$kSCValNetSMBNetBIOSNodeTypePeer@^{__CFString=}$"""
enums = """$kSCBondStatusLinkInvalid@1$kSCBondStatusNoPartner@2$kSCBondStatusNotInActiveGroup@3$kSCBondStatusOK@0$kSCBondStatusUnknown@999$kSCNetworkConnectionConnected@2$kSCNetworkConnectionConnecting@1$kSCNetworkConnectionDisconnected@0$kSCNetworkConnectionDisconnecting@3$kSCNetworkConnectionInvalid@-1$kSCNetworkConnectionPPPAuthenticating@5$kSCNetworkConnectionPPPConnected@8$kSCNetworkConnectionPPPConnectingLink@2$kSCNetworkConnectionPPPDialOnTraffic@3$kSCNetworkConnectionPPPDisconnected@0$kSCNetworkConnectionPPPDisconnectingLink@10$kSCNetworkConnectionPPPHoldingLinkOff@11$kSCNetworkConnectionPPPInitializing@1$kSCNetworkConnectionPPPNegotiatingLink@4$kSCNetworkConnectionPPPNegotiatingNetwork@7$kSCNetworkConnectionPPPSuspended@12$kSCNetworkConnectionPPPTerminating@9$kSCNetworkConnectionPPPWaitingForCallBack@6$kSCNetworkConnectionPPPWaitingForRedial@13$kSCNetworkFlagsConnectionAutomatic@8$kSCNetworkFlagsConnectionRequired@4$kSCNetworkFlagsInterventionRequired@16$kSCNetworkFlagsIsDirect@131072$kSCNetworkFlagsIsLocalAddress@65536$kSCNetworkFlagsReachable@2$kSCNetworkFlagsTransientConnection@1$kSCNetworkReachabilityFlagsConnectionAutomatic@8$kSCNetworkReachabilityFlagsConnectionOnDemand@32$kSCNetworkReachabilityFlagsConnectionOnTraffic@8$kSCNetworkReachabilityFlagsConnectionRequired@4$kSCNetworkReachabilityFlagsInterventionRequired@16$kSCNetworkReachabilityFlagsIsDirect@131072$kSCNetworkReachabilityFlagsIsLocalAddress@65536$kSCNetworkReachabilityFlagsIsWWAN@262144$kSCNetworkReachabilityFlagsReachable@2$kSCNetworkReachabilityFlagsTransientConnection@1$kSCPreferencesNotificationApply@2$kSCPreferencesNotificationCommit@1$kSCStatusAccessError@1003$kSCStatusConnectionIgnore@5002$kSCStatusConnectionNoService@5001$kSCStatusFailed@1001$kSCStatusInvalidArgument@1002$kSCStatusKeyExists@1005$kSCStatusLocked@1006$kSCStatusMaxLink@3006$kSCStatusNeedLock@1007$kSCStatusNoConfigFile@3003$kSCStatusNoKey@1004$kSCStatusNoLink@3004$kSCStatusNoPrefsSession@3001$kSCStatusNoStoreServer@2002$kSCStatusNoStoreSession@2001$kSCStatusNotifierActive@2003$kSCStatusOK@0$kSCStatusPrefsBusy@3002$kSCStatusReachabilityUnknown@4001$kSCStatusStale@3005$"""
misc.update(
    {
        "kSCNetworkConnectionSelectionOptionOnDemandHostName": "OnDemandHostName",
        "kSCNetworkConnectionPacketsOut": "PacketsOut",
        "kSCNetworkConnectionBytesIn": "BytesIn",
        "kSCNetworkConnectionPacketsIn": "PacketsIn",
        "kSCNetworkConnectionErrorsIn": "ErrorsIn",
        "kSCNetworkConnectionBytesOut": "BytesOut",
        "kSCNetworkConnectionSelectionOptionOnDemandRetry": "OnDemandRetry",
        "kSCNetworkConnectionErrorsOut": "ErrorsOut",
    }
)
functions = {
    "SCBondInterfaceCopyAll": (
        b"^{__CFArray=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCPreferencesGetTypeID": (b"Q",),
    "SCPreferencesSetValue": (b"Z^{__SCPreferences=}^{__CFString=}@",),
    "SCNetworkServiceEstablishDefaultConfiguration": (b"Z^{__SCNetworkService=}",),
    "SCNetworkServiceCreate": (
        b"^{__SCNetworkService=}^{__SCPreferences=}^{__SCNetworkInterface=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CNMarkPortalOnline": (b"Z^{__CFString=}",),
    "SCNetworkInterfaceCreateWithInterface": (
        b"^{__SCNetworkInterface=}^{__SCNetworkInterface=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreCopyDHCPInfo": (
        b"^{__CFDictionary=}^{__SCDynamicStore=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkSetCopyServices": (
        b"^{__CFArray=}^{__SCNetworkSet=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkSetSetCurrent": (b"Z^{__SCNetworkSet=}",),
    "SCDynamicStoreCopyComputerName": (
        b"^{__CFString=}^{__SCDynamicStore=}^I",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "o"}},
        },
    ),
    "SCNetworkConnectionScheduleWithRunLoop": (
        b"Z^{__SCNetworkConnection=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "SCDynamicStoreNotifyValue": (b"Z^{__SCDynamicStore=}^{__CFString=}",),
    "SCDynamicStoreCopyLocalHostName": (
        b"^{__CFString=}^{__SCDynamicStore=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceGetInterface": (
        b"^{__SCNetworkInterface=}^{__SCNetworkInterface=}",
    ),
    "SCNetworkSetRemoveService": (b"Z^{__SCNetworkSet=}^{__SCNetworkService=}",),
    "SCVLANInterfaceCopyAll": (
        b"^{__CFArray=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkProtocolGetConfiguration": (
        b"^{__CFDictionary=}^{__SCNetworkProtocol=}",
    ),
    "SCDynamicStoreCreateWithOptions": (
        b"^{__SCDynamicStore=}^{__CFAllocator=}^{__CFString=}^{__CFDictionary=}^?^{?=q^v^?^?^?}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__SCDynamicStore=}"},
                            1: {"type": b"^{__CFArray=}"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "SCVLANInterfaceCreate": (
        b"^{__SCNetworkInterface=}^{__SCPreferences=}^{__SCNetworkInterface=}^{__CFNumber=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkServiceGetInterface": (
        b"^{__SCNetworkInterface=}^{__SCNetworkService=}",
    ),
    "SCDynamicStoreKeyCreateProxies": (
        b"^{__CFString=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkReachabilityScheduleWithRunLoop": (
        b"Z^{__SCNetworkReachability=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "SCDynamicStoreAddTemporaryValue": (b"Z^{__SCDynamicStore=}^{__CFString=}@",),
    "SCNetworkConnectionStop": (b"Z^{__SCNetworkConnection=}Z",),
    "SCBondInterfaceCopyAvailableMemberInterfaces": (
        b"^{__CFArray=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkServiceAddProtocolType": (b"Z^{__SCNetworkService=}^{__CFString=}",),
    "SCDynamicStoreCreate": (
        b"^{__SCDynamicStore=}^{__CFAllocator=}^{__CFString=}^?^{?=q^v^?^?^?}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__SCDynamicStore=}"},
                            1: {"type": b"^{__CFArray=}"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "SCPreferencesPathCreateUniqueChild": (
        b"^{__CFString=}^{__SCPreferences=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkServiceGetServiceID": (b"^{__CFString=}^{__SCNetworkService=}",),
    "SCBondInterfaceCreate": (
        b"^{__SCNetworkInterface=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkConnectionCopyUserOptions": (
        b"^{__CFDictionary=}^{__SCNetworkConnection=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkReachabilitySetDispatchQueue": (b"Z^{__SCNetworkReachability=}@",),
    "SCPreferencesAddValue": (b"Z^{__SCPreferences=}^{__CFString=}@",),
    "SCDynamicStoreKeyCreateHostNames": (
        b"^{__CFString=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CNMarkPortalOffline": (b"Z^{__CFString=}",),
    "SCPreferencesCreate": (
        b"^{__SCPreferences=}^{__CFAllocator=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCVLANInterfaceSetOptions": (b"Z^{__SCNetworkInterface=}^{__CFDictionary=}",),
    "SCDynamicStoreSetMultiple": (
        b"Z^{__SCDynamicStore=}^{__CFDictionary=}^{__CFArray=}^{__CFArray=}",
    ),
    "SCNetworkConnectionCopyUserPreferences": (
        b"Z^{__CFDictionary=}^^{__CFString}^^{__CFDictionary}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {"already_cfretained": True, "type_modifier": "o"},
                2: {"already_cfretained": True, "type_modifier": "o"},
            },
        },
    ),
    "SCNetworkInterfaceGetBSDName": (b"^{__CFString=}^{__SCNetworkInterface=}",),
    "SCNetworkInterfaceSetExtendedConfiguration": (
        b"Z^{__SCNetworkInterface=}^{__CFString=}^{__CFDictionary=}",
    ),
    "SCNetworkCheckReachabilityByName": (
        b"Z*^I",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "SCNetworkInterfaceCopyMediaSubTypes": (
        b"^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCErrorString": (b"*i",),
    "DHCPClientPreferencesCopyApplicationOptions": (
        b"^C^{__CFString=}^i",
        "",
        {
            "retval": {
                "free_result": True,
                "already_cfretained": True,
                "c_array_length_in_arg": 1,
            },
            "arguments": {1: {"type_modifier": "o"}},
        },
    ),
    "SCNetworkProtocolGetProtocolType": (b"^{__CFString=}^{__SCNetworkProtocol=}",),
    "SCBondStatusGetTypeID": (b"Q",),
    "SCPreferencesCreateWithAuthorization": (
        b"^{__SCPreferences=}^{__CFAllocator=}^{__CFString=}^{__CFString=}^{AuthorizationOpaqueRef=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCBondInterfaceSetLocalizedDisplayName": (
        b"Z^{__SCNetworkInterface=}^{__CFString=}",
    ),
    "SCDynamicStoreKeyCreateConsoleUser": (
        b"^{__CFString=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkServiceSetName": (b"Z^{__SCNetworkService=}^{__CFString=}",),
    "SCDynamicStoreSetNotificationKeys": (
        b"Z^{__SCDynamicStore=}^{__CFArray=}^{__CFArray=}",
    ),
    "SCDynamicStoreKeyCreateNetworkInterface": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceSetMediaOptions": (
        b"Z^{__SCNetworkInterface=}^{__CFString=}^{__CFArray=}",
    ),
    "SCPreferencesGetValue": (b"@^{__SCPreferences=}^{__CFString=}",),
    "SCNetworkInterfaceGetConfiguration": (
        b"^{__CFDictionary=}^{__SCNetworkInterface=}",
    ),
    "DHCPInfoGetLeaseStartTime": (b"^{__CFDate=}^{__CFDictionary=}",),
    "SCNetworkInterfaceGetExtendedConfiguration": (
        b"^{__CFDictionary=}^{__SCNetworkInterface=}^{__CFString=}",
    ),
    "SCVLANInterfaceGetPhysicalInterface": (
        b"^{__SCNetworkInterface=}^{__SCNetworkInterface=}",
    ),
    "SCNetworkConnectionCopyServiceID": (
        b"^{__CFString=}^{__SCNetworkConnection=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreGetTypeID": (b"Q",),
    "SCNetworkSetCopy": (
        b"^{__SCNetworkSet=}^{__SCPreferences=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCBondStatusGetMemberInterfaces": (b"^{__CFArray=}^{__SCBondStatus=}",),
    "SCNetworkProtocolSetEnabled": (b"Z^{__SCNetworkProtocol=}Z",),
    "SCNetworkConnectionUnscheduleFromRunLoop": (
        b"Z^{__SCNetworkConnection=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "SCPreferencesSynchronize": (b"v^{__SCPreferences=}",),
    "SCPreferencesSetComputerName": (b"Z^{__SCPreferences=}^{__CFString=}I",),
    "SCVLANInterfaceRemove": (b"Z^{__SCNetworkInterface=}",),
    "SCDynamicStoreKeyCreateNetworkInterfaceEntity": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreCopyConsoleUser": (
        b"^{__CFString=}^{__SCDynamicStore=}^I^I",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}},
        },
    ),
    "SCVLANInterfaceCopyAvailablePhysicalInterfaces": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkConnectionCreateWithServiceID": (
        b"^{__SCNetworkConnection=}^{__CFAllocator=}^{__CFString=}^?^{?=q^v^?^?^?}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__SCNetworkConnection=}"},
                            1: {"type": b"i"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "SCNetworkServiceGetTypeID": (b"Q",),
    "SCCopyLastError": (b"^{__CFError=}", "", {"retval": {"already_cfretained": True}}),
    "SCNetworkServiceRemoveProtocolType": (b"Z^{__SCNetworkService=}^{__CFString=}",),
    "SCDynamicStoreKeyCreateComputerName": (
        b"^{__CFString=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCPreferencesUnscheduleFromRunLoop": (
        b"Z^{__SCPreferences=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "SCNetworkReachabilityCreateWithName": (
        b"^{__SCNetworkReachability=}^{__CFAllocator=}*",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCBondInterfaceRemove": (b"Z^{__SCNetworkInterface=}",),
    "SCNetworkCheckReachabilityByAddress": (
        b"Z^{sockaddr=CC[14c]}I^I",
        "",
        {"arguments": {0: {"type_modifier": "n"}, 2: {"type_modifier": "o"}}},
    ),
    "SCNetworkSetContainsInterface": (b"Z^{__SCNetworkSet=}^{__SCNetworkInterface=}",),
    "SCNetworkServiceRemove": (b"Z^{__SCNetworkService=}",),
    "SCPreferencesApplyChanges": (b"Z^{__SCPreferences=}",),
    "CNCopySupportedInterfaces": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCBondInterfaceGetMemberInterfaces": (b"^{__CFArray=}^{__SCNetworkInterface=}",),
    "SCPreferencesPathGetLink": (b"^{__CFString=}^{__SCPreferences=}^{__CFString=}",),
    "SCPreferencesPathSetLink": (b"Z^{__SCPreferences=}^{__CFString=}^{__CFString=}",),
    "SCNetworkInterfaceGetHardwareAddressString": (
        b"^{__CFString=}^{__SCNetworkInterface=}",
    ),
    "SCNetworkSetGetTypeID": (b"Q",),
    "SCNetworkReachabilityUnscheduleFromRunLoop": (
        b"Z^{__SCNetworkReachability=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "SCNetworkServiceSetEnabled": (b"Z^{__SCNetworkService=}Z",),
    "SCPreferencesSetDispatchQueue": (b"Z^{__SCPreferences=}@",),
    "SCNetworkReachabilityGetTypeID": (b"Q",),
    "SCDynamicStoreAddValue": (b"Z^{__SCDynamicStore=}^{__CFString=}@",),
    "SCNetworkServiceGetEnabled": (b"Z^{__SCNetworkService=}",),
    "SCNetworkSetAddService": (b"Z^{__SCNetworkSet=}^{__SCNetworkService=}",),
    "SCNetworkConnectionGetTypeID": (b"Q",),
    "SCDynamicStoreCopyValue": (
        b"@^{__SCDynamicStore=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCBondInterfaceSetMemberInterfaces": (b"Z^{__SCNetworkInterface=}^{__CFArray=}",),
    "DHCPInfoGetOptionData": (b"^{__CFData=}^{__CFDictionary=}C",),
    "SCDynamicStoreCopyMultiple": (
        b"^{__CFDictionary=}^{__SCDynamicStore=}^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCBondStatusGetInterfaceStatus": (
        b"^{__CFDictionary=}^{__SCBondStatus=}^{__SCNetworkInterface=}",
    ),
    "SCNetworkConnectionCopyExtendedStatus": (
        b"^{__CFDictionary=}^{__SCNetworkConnection=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkProtocolGetTypeID": (b"Q",),
    "SCNetworkSetGetName": (b"^{__CFString=}^{__SCNetworkSet=}",),
    "SCPreferencesSetCallback": (
        b"Z^{__SCPreferences=}^?^{?=q^v^?^?^?}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__SCPreferences=}"},
                            1: {"type": b"I"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "SCNetworkInterfaceGetSupportedProtocolTypes": (
        b"^{__CFArray=}^{__SCNetworkInterface=}",
    ),
    "SCNetworkServiceCopyProtocol": (
        b"^{__SCNetworkProtocol=}^{__SCNetworkService=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreRemoveValue": (b"Z^{__SCDynamicStore=}^{__CFString=}",),
    "SCVLANInterfaceGetTag": (b"^{__CFNumber=}^{__SCNetworkInterface=}",),
    "SCNetworkServiceCopy": (
        b"^{__SCNetworkService=}^{__SCPreferences=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreCopyKeyList": (
        b"^{__CFArray=}^{__SCDynamicStore=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceGetLocalizedDisplayName": (
        b"^{__CFString=}^{__SCNetworkInterface=}",
    ),
    "SCDynamicStoreCopyNotifiedKeys": (
        b"^{__CFArray=}^{__SCDynamicStore=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceCopyMediaSubTypeOptions": (
        b"^{__CFArray=}^{__CFArray=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "DHCPInfoGetLeaseExpirationTime": (b"^{__CFDate=}^{__CFDictionary=}",),
    "SCVLANInterfaceSetLocalizedDisplayName": (
        b"Z^{__SCNetworkInterface=}^{__CFString=}",
    ),
    "SCVLANInterfaceSetPhysicalInterfaceAndTag": (
        b"Z^{__SCNetworkInterface=}^{__SCNetworkInterface=}^{__CFNumber=}",
    ),
    "SCNetworkProtocolSetConfiguration": (
        b"Z^{__SCNetworkProtocol=}^{__CFDictionary=}",
    ),
    "SCBondInterfaceGetOptions": (b"^{__CFDictionary=}^{__SCNetworkInterface=}",),
    "SCBondInterfaceCopyStatus": (
        b"^{__SCBondStatus=}^{__SCNetworkInterface=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceGetTypeID": (b"Q",),
    "CNCopyCurrentNetworkInfo": (
        b"^{__CFDictionary=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CNSetSupportedSSIDs": (b"Z^{__CFArray=}",),
    "SCNetworkConnectionCopyStatistics": (
        b"^{__CFDictionary=}^{__SCNetworkConnection=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreKeyCreate": (
        b"^{__CFString=}^{__CFAllocator=}@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"printf_format": True}},
            "variadic": True,
        },
    ),
    "SCPreferencesCommitChanges": (b"Z^{__SCPreferences=}",),
    "SCNetworkSetSetServiceOrder": (b"Z^{__SCNetworkSet=}^{__CFArray=}",),
    "SCPreferencesLock": (b"Z^{__SCPreferences=}Z",),
    "SCNetworkSetCopyAll": (
        b"^{__CFArray=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceRefreshConfiguration": (b"Z^{__CFString=}",),
    "SCNetworkSetSetName": (b"Z^{__SCNetworkSet=}^{__CFString=}",),
    "SCPreferencesPathRemoveValue": (b"Z^{__SCPreferences=}^{__CFString=}",),
    "SCDynamicStoreCopyProxies": (
        b"^{__CFDictionary=}^{__SCDynamicStore=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkServiceGetName": (b"^{__CFString=}^{__SCNetworkService=}",),
    "SCNetworkServiceCopyAll": (
        b"^{__CFArray=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceSetMTU": (b"Z^{__SCNetworkInterface=}i",),
    "DHCPClientPreferencesSetApplicationOptions": (
        b"Z^{__CFString=}^Cq",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}}},
    ),
    "SCDynamicStoreKeyCreateNetworkGlobalEntity": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkSetCopyCurrent": (
        b"^{__SCNetworkSet=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkInterfaceCopyAll": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCPreferencesRemoveValue": (b"Z^{__SCPreferences=}^{__CFString=}",),
    "SCPreferencesPathGetValue": (
        b"^{__CFDictionary=}^{__SCPreferences=}^{__CFString=}",
    ),
    "SCDynamicStoreSetValue": (b"Z^{__SCDynamicStore=}^{__CFString=}@",),
    "SCNetworkConnectionGetStatus": (b"i^{__SCNetworkConnection=}",),
    "SCNetworkServiceCopyProtocols": (
        b"^{__CFArray=}^{__SCNetworkService=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreCopyLocation": (
        b"^{__CFString=}^{__SCDynamicStore=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkReachabilityCreateWithAddress": (
        b"^{__SCNetworkReachability=}^{__CFAllocator=}^{sockaddr=CC[14c]}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "n"}},
        },
    ),
    "SCNetworkSetRemove": (b"Z^{__SCNetworkSet=}",),
    "SCNetworkInterfaceSetConfiguration": (
        b"Z^{__SCNetworkInterface=}^{__CFDictionary=}",
    ),
    "SCPreferencesSetLocalHostName": (b"Z^{__SCPreferences=}^{__CFString=}",),
    "SCNetworkInterfaceGetInterfaceType": (b"^{__CFString=}^{__SCNetworkInterface=}",),
    "SCPreferencesGetSignature": (b"^{__CFData=}^{__SCPreferences=}",),
    "SCNetworkConnectionStart": (b"Z^{__SCNetworkConnection=}^{__CFDictionary=}Z",),
    "SCNetworkInterfaceCopyMTU": (
        b"Z^{__SCNetworkInterface=}^i^i^i",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {"type_modifier": "o"},
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
            },
        },
    ),
    "SCNetworkSetGetServiceOrder": (b"^{__CFArray=}^{__SCNetworkSet=}",),
    "SCDynamicStoreKeyCreateLocation": (
        b"^{__CFString=}^{__CFAllocator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCBondInterfaceSetOptions": (b"Z^{__SCNetworkInterface=}^{__CFDictionary=}",),
    "SCDynamicStoreCreateRunLoopSource": (
        b"^{__CFRunLoopSource=}^{__CFAllocator=}^{__SCDynamicStore=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkProtocolGetEnabled": (b"Z^{__SCNetworkProtocol=}",),
    "SCNetworkSetCreate": (
        b"^{__SCNetworkSet=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkConnectionSetDispatchQueue": (b"Z^{__SCNetworkConnection=}@",),
    "SCDynamicStoreKeyCreateNetworkServiceEntity": (
        b"^{__CFString=}^{__CFAllocator=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCDynamicStoreSetDispatchQueue": (b"Z^{__SCDynamicStore=}@",),
    "SCNetworkReachabilitySetCallback": (
        b"Z^{__SCNetworkReachability=}^?^{?=q^v^?^?^?}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{__SCNetworkReachability=}"},
                            1: {"type": b"I"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "SCNetworkInterfaceGetSupportedInterfaceTypes": (
        b"^{__CFArray=}^{__SCNetworkInterface=}",
    ),
    "SCPreferencesCopyKeyList": (
        b"^{__CFArray=}^{__SCPreferences=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SCNetworkReachabilityCreateWithAddressPair": (
        b"^{__SCNetworkReachability=}^{__CFAllocator=}^{sockaddr=CC[14c]}^{sockaddr=CC[14c]}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "n"}, 2: {"type_modifier": "n"}},
        },
    ),
    "SCNetworkInterfaceForceConfigurationRefresh": (b"Z^{__SCNetworkInterface=}",),
    "SCNetworkSetGetSetID": (b"^{__CFString=}^{__SCNetworkSet=}",),
    "SCNetworkInterfaceCopyMediaOptions": (
        b"Z^{__SCNetworkInterface=}^^{__CFDictionary}^^{__CFDictionary}^^{__CFArray}Z",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {"type_modifier": "o"},
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
            },
        },
    ),
    "SCPreferencesScheduleWithRunLoop": (
        b"Z^{__SCPreferences=}^{__CFRunLoop=}^{__CFString=}",
    ),
    "SCVLANInterfaceGetOptions": (b"^{__CFDictionary=}^{__SCNetworkInterface=}",),
    "SCNetworkReachabilityGetFlags": (
        b"Z^{__SCNetworkReachability=}^I",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "SCPreferencesPathSetValue": (
        b"Z^{__SCPreferences=}^{__CFString=}^{__CFDictionary=}",
    ),
    "SCPreferencesUnlock": (b"Z^{__SCPreferences=}",),
    "SCError": (b"i",),
}
aliases = {
    "kSCPropNetDNSSearchOrder": "kSCPropNetDNSSearchOrder",
    "kSCPropNetPPPAuthEAPPlugins": "kSCPropNetPPPAuthEAPPlugins",
    "kSCPropNet6to4Relay": "kSCPropNet6to4Relay",
    "kSCPropUserDefinedName": "kSCPropUserDefinedName",
    "kSCPropNetProxiesSOCKSProxy": "kSCPropNetProxiesSOCKSProxy",
    "kSCValNetIPSecSharedSecretEncryptionKeychain": "kSCValNetIPSecSharedSecretEncryptionKeychain",
    "kSCPropNetPPPDisconnectOnFastUserSwitch": "kSCPropNetPPPDisconnectOnFastUserSwitch",
    "kSCPropNetEthernetMediaSubType": "kSCPropNetEthernetMediaSubType",
    "kSCPropNetPPPCommDisplayTerminalWindow": "kSCPropNetPPPCommDisplayTerminalWindow",
    "kSCPropNetModemConnectionScript": "kSCPropNetModemConnectionScript",
    "kSCValNetPPPAuthPromptAfter": "kSCValNetPPPAuthPromptAfter",
    "kSCPropNetIPSecRemoteAddress": "kSCPropNetIPSecRemoteAddress",
    "kSCPropNetProxiesGopherEnable": "kSCPropNetProxiesGopherEnable",
    "kSCPropNetIPv4DHCPClientID": "kSCPropNetIPv4DHCPClientID",
    "kSCPrefSets": "kSCPrefSets",
    "kSCValNetIPSecLocalIdentifierTypeKeyID": "kSCValNetIPSecLocalIdentifierTypeKeyID",
    "kSCValNetIPSecAuthenticationMethodHybrid": "kSCValNetIPSecAuthenticationMethodHybrid",
    "kSCPropNetModemDeviceContextID": "kSCPropNetModemDeviceContextID",
    "kSCValNetIPv6ConfigMethodManual": "kSCValNetIPv6ConfigMethodManual",
    "kSCPropNetPPPIdleReminderTimer": "kSCPropNetPPPIdleReminderTimer",
    "kSCPropNetModemAccessPointName": "kSCPropNetModemAccessPointName",
    "kSCPropNetModemConnectSpeed": "kSCPropNetModemConnectSpeed",
    "kSCPropNetDNSSupplementalMatchDomains": "kSCPropNetDNSSupplementalMatchDomains",
    "kSCPropNetPPPLCPEchoEnabled": "kSCPropNetPPPLCPEchoEnabled",
    "kSCPropNetProxiesExceptionsList": "kSCPropNetProxiesExceptionsList",
    "kSCPropNetProxiesGopherProxy": "kSCPropNetProxiesGopherProxy",
    "kSCDynamicStoreDomainPlugin": "kSCDynamicStoreDomainPlugin",
    "kSCResvLink": "kSCResvLink",
    "kSCPropNetPPPOverridePrimary": "kSCPropNetPPPOverridePrimary",
    "kSCValNetIPSecXAuthPasswordEncryptionKeychain": "kSCValNetIPSecXAuthPasswordEncryptionKeychain",
    "kSCValNetL2TPTransportIP": "kSCValNetL2TPTransportIP",
    "kSCPropNetIPSecLocalCertificate": "kSCPropNetIPSecLocalCertificate",
    "kSCEntUsersConsoleUser": "kSCEntUsersConsoleUser",
    "kSCPropNetIPv4ConfigMethod": "kSCPropNetIPv4ConfigMethod",
    "kSCPropNetProxiesProxyAutoConfigURLString": "kSCPropNetProxiesProxyAutoConfigURLString",
    "kSCPrefCurrentSet": "kSCPrefCurrentSet",
    "kSCPropNetPPPDialOnDemand": "kSCPropNetPPPDialOnDemand",
    "kSCPropNetIPv6ConfigMethod": "kSCPropNetIPv6ConfigMethod",
    "kSCValNetIPv6ConfigMethod6to4": "kSCValNetIPv6ConfigMethod6to4",
    "kSCPropNetPPPLCPCompressionPField": "kSCPropNetPPPLCPCompressionPField",
    "kSCPropNetPPPRetryConnectTime": "kSCPropNetPPPRetryConnectTime",
    "kSCPropNetProxiesGopherPort": "kSCPropNetProxiesGopherPort",
    "kSCEntNetDHCP": "kSCEntNetDHCP",
    "kSCEntNetInterface": "kSCEntNetInterface",
    "kSCPropNetProxiesHTTPSEnable": "kSCPropNetProxiesHTTPSEnable",
    "kSCPropNetInterfaceHardware": "kSCPropNetInterfaceHardware",
    "kSCPropNetModemNote": "kSCPropNetModemNote",
    "kSCPropNetAirPortAllowNetCreation": "kSCPropNetAirPortAllowNetCreation",
    "kSCDynamicStorePropNetServiceIDs": "kSCDynamicStorePropNetServiceIDs",
    "kSCResvInactive": "kSCResvInactive",
    "kSCPropNetPPPLCPMTU": "kSCPropNetPPPLCPMTU",
    "kSCPropNetEthernetMediaOptions": "kSCPropNetEthernetMediaOptions",
    "kSCValNetPPPAuthPromptBefore": "kSCValNetPPPAuthPromptBefore",
    "kSCPropNetInterfaceSupportsModemOnHold": "kSCPropNetInterfaceSupportsModemOnHold",
    "kSCPropUsersConsoleUserUID": "kSCPropUsersConsoleUserUID",
    "kSCPropNetL2TPIPSecSharedSecret": "kSCPropNetL2TPIPSecSharedSecret",
    "kSCValNetIPv4ConfigMethodLinkLocal": "kSCValNetIPv4ConfigMethodLinkLocal",
    "kSCPropNetProxiesHTTPEnable": "kSCPropNetProxiesHTTPEnable",
    "kSCPropNetModemDeviceVendor": "kSCPropNetModemDeviceVendor",
    "kSCPropNetIPv4SubnetMasks": "kSCPropNetIPv4SubnetMasks",
    "kSCPropNetProxiesHTTPSPort": "kSCPropNetProxiesHTTPSPort",
    "kSCPropNetPPPIdleReminder": "kSCPropNetPPPIdleReminder",
    "kSCValNetAirPortJoinModeAutomatic": "kSCValNetAirPortJoinModeAutomatic",
    "kSCDynamicStorePropNetPrimaryInterface": "kSCDynamicStorePropNetPrimaryInterface",
    "kSCEntNetEthernet": "kSCEntNetEthernet",
    "kSCPropNetIPv6Addresses": "kSCPropNetIPv6Addresses",
    "kSCDynamicStoreDomainFile": "kSCDynamicStoreDomainFile",
    "kSCPropNetPPPDisconnectOnLogout": "kSCPropNetPPPDisconnectOnLogout",
    "kSCDynamicStorePropNetPrimaryService": "kSCDynamicStorePropNetPrimaryService",
    "kSCPropNetPPPCommRedialInterval": "kSCPropNetPPPCommRedialInterval",
    "kSCValNetIPSecAuthenticationMethodSharedSecret": "kSCValNetIPSecAuthenticationMethodSharedSecret",
    "kSCPropNetPPPAuthProtocol": "kSCPropNetPPPAuthProtocol",
    "kSCValNetIPv4ConfigMethodBOOTP": "kSCValNetIPv4ConfigMethodBOOTP",
    "kSCDynamicStoreDomainState": "kSCDynamicStoreDomainState",
    "kSCPropUsersConsoleUserGID": "kSCPropUsersConsoleUserGID",
    "kSCPropNetInterfaceDeviceName": "kSCPropNetInterfaceDeviceName",
    "kSCPropNetModemHoldEnabled": "kSCPropNetModemHoldEnabled",
    "kSCEntNetFireWire": "kSCEntNetFireWire",
    "kSCPrefNetworkServices": "kSCPrefNetworkServices",
    "kSCValNetInterfaceTypeFireWire": "kSCValNetInterfaceTypeFireWire",
    "kSCPropNetModemDialMode": "kSCPropNetModemDialMode",
    "kSCValNetInterfaceTypePPP": "kSCValNetInterfaceTypePPP",
    "kSCPropNetPPPLogfile": "kSCPropNetPPPLogfile",
    "kSCPropNetModemSpeed": "kSCPropNetModemSpeed",
    "kSCPropNetLinkActive": "kSCPropNetLinkActive",
    "kSCValNetIPSecAuthenticationMethodCertificate": "kSCValNetIPSecAuthenticationMethodCertificate",
    "kSCPropNetModemDeviceModel": "kSCPropNetModemDeviceModel",
    "kSCPropNetIPv6Router": "kSCPropNetIPv6Router",
    "kSCPropNetIPSecConnectTime": "kSCPropNetIPSecConnectTime",
    "kSCPropNetEthernetMTU": "kSCPropNetEthernetMTU",
    "kSCPropNetProxiesRTSPProxy": "kSCPropNetProxiesRTSPProxy",
    "kSCPropNetIPSecXAuthName": "kSCPropNetIPSecXAuthName",
    "kSCPropNetL2TPTransport": "kSCPropNetL2TPTransport",
    "kSCValNetIPv6ConfigMethodRouterAdvertisement": "kSCValNetIPv6ConfigMethodRouterAdvertisement",
    "kSCPropNetDNSServerPort": "kSCPropNetDNSServerPort",
    "kSCPropNetDNSSupplementalMatchOrders": "kSCPropNetDNSSupplementalMatchOrders",
    "kSCPropNetSMBWorkgroup": "kSCPropNetSMBWorkgroup",
    "kSCPropSystemComputerName": "kSCPropSystemComputerName",
    "kSCValNetInterfaceSubTypePPPoE": "kSCValNetInterfaceSubTypePPPoE",
    "kSCPropNetPPPAuthName": "kSCPropNetPPPAuthName",
    "kSCDynamicStoreDomainSetup": "kSCDynamicStoreDomainSetup",
    "kSCPropNetProxiesFTPProxy": "kSCPropNetProxiesFTPProxy",
    "kSCPropNetPPPCCPMPPE40Enabled": "kSCPropNetPPPCCPMPPE40Enabled",
    "kSCPropNetModemPulseDial": "kSCPropNetModemPulseDial",
    "kSCPropNetLinkDetaching": "kSCPropNetLinkDetaching",
    "kSCPropUsersConsoleUserName": "kSCPropUsersConsoleUserName",
    "kSCPropNetIPv6DestAddresses": "kSCPropNetIPv6DestAddresses",
    "kSCPropVersion": "kSCPropVersion",
    "kSCCompNetwork": "kSCCompNetwork",
    "kSCPropNetIPv6Flags": "kSCPropNetIPv6Flags",
    "kSCPrefSystem": "kSCPrefSystem",
    "kSCValNetIPv4ConfigMethodManual": "kSCValNetIPv4ConfigMethodManual",
    "kSCValNetInterfaceSubTypePPPSerial": "kSCValNetInterfaceSubTypePPPSerial",
    "kSCPropNetModemHoldDisconnectOnAnswer": "kSCPropNetModemHoldDisconnectOnAnswer",
    "kSCEntNetPPP": "kSCEntNetPPP",
    "kSCPropNetPPPLastCause": "kSCPropNetPPPLastCause",
    "kSCPropNetAirPortAuthPasswordEncryption": "kSCPropNetAirPortAuthPasswordEncryption",
    "kSCPropNetPPPCommConnectDelay": "kSCPropNetPPPCommConnectDelay",
    "kSCPropNetSMBNetBIOSName": "kSCPropNetSMBNetBIOSName",
    "kSCPropNetProxiesHTTPSProxy": "kSCPropNetProxiesHTTPSProxy",
    "kSCPropNetProxiesProxyAutoConfigEnable": "kSCPropNetProxiesProxyAutoConfigEnable",
    "kSCValNetInterfaceTypeIPSec": "kSCValNetInterfaceTypeIPSec",
    "kSCPropNetIPSecLocalIdentifierType": "kSCPropNetIPSecLocalIdentifierType",
    "kSCValNetInterfaceTypeEthernet": "kSCValNetInterfaceTypeEthernet",
    "kSCValNetPPPAuthProtocolCHAP": "kSCValNetPPPAuthProtocolCHAP",
    "kSCPropNetModemHoldCallWaitingAudibleAlert": "kSCPropNetModemHoldCallWaitingAudibleAlert",
    "kSCPropNetPPPAuthPasswordEncryption": "kSCPropNetPPPAuthPasswordEncryption",
    "kSCValNetInterfaceSubTypeL2TP": "kSCValNetInterfaceSubTypeL2TP",
    "kSCDynamicStorePropNetInterfaces": "kSCDynamicStorePropNetInterfaces",
    "kSCPropNetIPv6PrefixLength": "kSCPropNetIPv6PrefixLength",
    "kSCValNetInterfaceSubTypePPTP": "kSCValNetInterfaceSubTypePPTP",
    "kSCPropNetPPPCommAlternateRemoteAddress": "kSCPropNetPPPCommAlternateRemoteAddress",
    "kSCPropNetIPSecXAuthEnabled": "kSCPropNetIPSecXAuthEnabled",
    "kSCPropNetSMBWINSAddresses": "kSCPropNetSMBWINSAddresses",
    "kSCPropNetPPPPlugins": "kSCPropNetPPPPlugins",
    "kSCDynamicStorePropSetupCurrentSet": "kSCDynamicStorePropSetupCurrentSet",
    "kSCPropNetInterfaceType": "kSCPropNetInterfaceType",
    "kSCPropNetModemSpeaker": "kSCPropNetModemSpeaker",
    "kSCPropNetPPPCCPEnabled": "kSCPropNetPPPCCPEnabled",
    "kSCPropNetPPPDisconnectOnSleep": "kSCPropNetPPPDisconnectOnSleep",
    "kSCPropNetProxiesExcludeSimpleHostnames": "kSCPropNetProxiesExcludeSimpleHostnames",
    "kSCEntNetLink": "kSCEntNetLink",
    "kSCPropNetPPPLCPEchoFailure": "kSCPropNetPPPLCPEchoFailure",
    "kSCPropNetAirPortAuthPassword": "kSCPropNetAirPortAuthPassword",
    "kSCPropNetIPv4BroadcastAddresses": "kSCPropNetIPv4BroadcastAddresses",
    "kSCValNetSMBNetBIOSNodeTypeBroadcast": "kSCValNetSMBNetBIOSNodeTypeBroadcast",
    "kSCEntNetModem": "kSCEntNetModem",
    "kSCPropNetIPSecStatus": "kSCPropNetIPSecStatus",
    "kSCPropNetPPPCommRedialCount": "kSCPropNetPPPCommRedialCount",
    "kSCPropNetSMBNetBIOSNodeType": "kSCPropNetSMBNetBIOSNodeType",
    "kSCValNetIPSecXAuthPasswordEncryptionPrompt": "kSCValNetIPSecXAuthPasswordEncryptionPrompt",
    "kSCCompGlobal": "kSCCompGlobal",
    "kSCPropNetProxiesHTTPPort": "kSCPropNetProxiesHTTPPort",
    "kSCPropSystemComputerNameEncoding": "kSCPropSystemComputerNameEncoding",
    "kSCPropNetModemErrorCorrection": "kSCPropNetModemErrorCorrection",
    "kSCPropNetProxiesSOCKSEnable": "kSCPropNetProxiesSOCKSEnable",
    "kSCValNetSMBNetBIOSNodeTypeHybrid": "kSCValNetSMBNetBIOSNodeTypeHybrid",
    "kSCPropNetPPPDisconnectOnIdle": "kSCPropNetPPPDisconnectOnIdle",
    "kSCValNetAirPortJoinModeStrongest": "kSCValNetAirPortJoinModeStrongest",
    "kSCPropNetPPPDisconnectOnIdleTimer": "kSCPropNetPPPDisconnectOnIdleTimer",
    "kSCPropNetIPSecSharedSecretEncryption": "kSCPropNetIPSecSharedSecretEncryption",
    "kSCEntNetAirPort": "kSCEntNetAirPort",
    "kSCEntNetProxies": "kSCEntNetProxies",
    "kSCValNetPPPAuthProtocolEAP": "kSCValNetPPPAuthProtocolEAP",
    "kSCValNetIPv4ConfigMethodPPP": "kSCValNetIPv4ConfigMethodPPP",
    "kSCPropNetPPPSessionTimer": "kSCPropNetPPPSessionTimer",
    "kSCValNetIPv6ConfigMethodAutomatic": "kSCValNetIPv6ConfigMethodAutomatic",
    "kSCPropNetPPPLCPReceiveACCM": "kSCPropNetPPPLCPReceiveACCM",
    "kSCValNetModemDialModeWaitForDialTone": "kSCValNetModemDialModeWaitForDialTone",
    "kSCValNetL2TPTransportIPSec": "kSCValNetL2TPTransportIPSec",
    "kSCPropNetProxiesProxyAutoDiscoveryEnable": "kSCPropNetProxiesProxyAutoDiscoveryEnable",
    "kSCPropNetProxiesRTSPPort": "kSCPropNetProxiesRTSPPort",
    "kSCPropNetDNSServerTimeout": "kSCPropNetDNSServerTimeout",
    "kSCNetworkReachabilityFlagsConnectionAutomatic": "kSCNetworkReachabilityFlagsConnectionOnTraffic",
    "kSCPropNetPPPLCPEchoInterval": "kSCPropNetPPPLCPEchoInterval",
    "SCVLANInterfaceRef": "SCNetworkInterfaceRef",
    "kSCValNetInterfaceType6to4": "kSCValNetInterfaceType6to4",
    "kSCPropNetPPPCommRedialEnabled": "kSCPropNetPPPCommRedialEnabled",
    "kSCValNetL2TPIPSecSharedSecretEncryptionKeychain": "kSCValNetL2TPIPSecSharedSecretEncryptionKeychain",
    "kSCEntNetL2TP": "kSCEntNetL2TP",
    "kSCPropNetPPPDisconnectTime": "kSCPropNetPPPDisconnectTime",
    "kSCEntNetSMB": "kSCEntNetSMB",
    "kSCPropNetPPPConnectTime": "kSCPropNetPPPConnectTime",
    "kSCValNetModemDialModeIgnoreDialTone": "kSCValNetModemDialModeIgnoreDialTone",
    "kSCPropNetDNSOptions": "kSCPropNetDNSOptions",
    "kSCPropNetProxiesFTPPort": "kSCPropNetProxiesFTPPort",
    "kSCCompInterface": "kSCCompInterface",
    "kSCValNetIPv4ConfigMethodINFORM": "kSCValNetIPv4ConfigMethodINFORM",
    "kSCCompService": "kSCCompService",
    "kSCEntNetPPPoE": "kSCEntNetPPPoE",
    "kSCPropNetIPv4Addresses": "kSCPropNetIPv4Addresses",
    "kSCPropNetPPPLCPCompressionACField": "kSCPropNetPPPLCPCompressionACField",
    "kSCPropNetIPSecLocalIdentifier": "kSCPropNetIPSecLocalIdentifier",
    "kSCPropNetProxiesFTPEnable": "kSCPropNetProxiesFTPEnable",
    "kSCPropNetDNSDomainName": "kSCPropNetDNSDomainName",
    "kSCValNetSMBNetBIOSNodeTypeMixed": "kSCValNetSMBNetBIOSNodeTypeMixed",
    "kSCEntNet6to4": "kSCEntNet6to4",
    "kSCValNetPPPAuthProtocolPAP": "kSCValNetPPPAuthProtocolPAP",
    "kSCValNetPPPAuthPasswordEncryptionKeychain": "kSCValNetPPPAuthPasswordEncryptionKeychain",
    "kSCValNetAirPortJoinModeRecent": "kSCValNetAirPortJoinModeRecent",
    "kSCPropNetLocalHostName": "kSCPropNetLocalHostName",
    "kSCValNetAirPortJoinModePreferred": "kSCValNetAirPortJoinModePreferred",
    "kSCDynamicStorePropSetupLastUpdated": "kSCDynamicStorePropSetupLastUpdated",
    "kSCPropNetIPv4Router": "kSCPropNetIPv4Router",
    "SCBondInterfaceRef": "SCNetworkInterfaceRef",
    "kSCPropNetIPSecXAuthPassword": "kSCPropNetIPSecXAuthPassword",
    "kSCPropNetDNSSearchDomains": "kSCPropNetDNSSearchDomains",
    "kSCPropNetAirPortPreferredNetwork": "kSCPropNetAirPortPreferredNetwork",
    "kSCPropNetDNSServerAddresses": "kSCPropNetDNSServerAddresses",
    "kSCPropNetL2TPIPSecSharedSecretEncryption": "kSCPropNetL2TPIPSecSharedSecretEncryption",
    "kSCPropNetIPv4DestAddresses": "kSCPropNetIPv4DestAddresses",
    "kSCEntNetDNS": "kSCEntNetDNS",
    "kSCPropNetProxiesProxyAutoConfigJavaScript": "kSCPropNetProxiesProxyAutoConfigJavaScript",
    "kSCPropNetPPPIPCPCompressionVJ": "kSCPropNetPPPIPCPCompressionVJ",
    "kSCCompHostNames": "kSCCompHostNames",
    "kSCPropNetAirPortSavePasswords": "kSCPropNetAirPortSavePasswords",
    "kSCCompAnyRegex": "kSCCompAnyRegex",
    "kSCValNetAirPortAuthPasswordEncryptionKeychain": "kSCValNetAirPortAuthPasswordEncryptionKeychain",
    "kSCCompSystem": "kSCCompSystem",
    "kSCPropNetIPSecAuthenticationMethod": "kSCPropNetIPSecAuthenticationMethod",
    "kSCCompUsers": "kSCCompUsers",
    "kSCPropNetPPPVerboseLogging": "kSCPropNetPPPVerboseLogging",
    "kSCDynamicStoreDomainPrefs": "kSCDynamicStoreDomainPrefs",
    "kSCValNetPPPAuthProtocolMSCHAP2": "kSCValNetPPPAuthProtocolMSCHAP2",
    "kSCPropNetAirPortPowerEnabled": "kSCPropNetAirPortPowerEnabled",
    "kSCPropNetInterfaceSubType": "kSCPropNetInterfaceSubType",
    "kSCPropNetIPSecXAuthPasswordEncryption": "kSCPropNetIPSecXAuthPasswordEncryption",
    "kSCValNetSMBNetBIOSNodeTypePeer": "kSCValNetSMBNetBIOSNodeTypePeer",
    "kSCPropNetProxiesSOCKSPort": "kSCPropNetProxiesSOCKSPort",
    "kSCValNetPPPAuthProtocolMSCHAP1": "kSCValNetPPPAuthProtocolMSCHAP1",
    "kSCPropNetSMBNetBIOSScope": "kSCPropNetSMBNetBIOSScope",
    "kSCEntNetPPPSerial": "kSCEntNetPPPSerial",
    "kSCPropNetPPPCCPMPPE128Enabled": "kSCPropNetPPPCCPMPPE128Enabled",
    "kSCValNetModemDialModeManual": "kSCValNetModemDialModeManual",
    "kSCPropNetPPPLCPTransmitACCM": "kSCPropNetPPPLCPTransmitACCM",
    "kSCPropMACAddress": "kSCPropMACAddress",
    "kSCPropNetServiceOrder": "kSCPropNetServiceOrder",
    "kSCPropNetPPPCommTerminalScript": "kSCPropNetPPPCommTerminalScript",
    "kSCValNetAirPortJoinModeRanked": "kSCValNetAirPortJoinModeRanked",
    "kSCPropNetModemHoldReminder": "kSCPropNetModemHoldReminder",
    "kSCValNetIPv4ConfigMethodDHCP": "kSCValNetIPv4ConfigMethodDHCP",
    "kSCPropNetPPPUseSessionTimer": "kSCPropNetPPPUseSessionTimer",
    "kSCPropNetIPSecSharedSecret": "kSCPropNetIPSecSharedSecret",
    "kSCPropNetModemDataCompression": "kSCPropNetModemDataCompression",
    "kSCPropInterfaceName": "kSCPropInterfaceName",
    "kSCPropNetPPPCommRemoteAddress": "kSCPropNetPPPCommRemoteAddress",
    "kSCPropNetDNSSortList": "kSCPropNetDNSSortList",
    "kSCPropNetAirPortJoinMode": "kSCPropNetAirPortJoinMode",
    "kSCEntNetIPSec": "kSCEntNetIPSec",
    "kSCEntNetPPTP": "kSCEntNetPPTP",
    "kSCPropNetPPPAuthPassword": "kSCPropNetPPPAuthPassword",
    "kSCPropNetProxiesHTTPProxy": "kSCPropNetProxiesHTTPProxy",
    "kSCPropNetModemConnectionPersonality": "kSCPropNetModemConnectionPersonality",
    "kSCPropNetPPPAuthPrompt": "kSCPropNetPPPAuthPrompt",
    "kSCPropNetPPPACSPEnabled": "kSCPropNetPPPACSPEnabled",
    "kSCPropNetProxiesRTSPEnable": "kSCPropNetProxiesRTSPEnable",
    "kSCPropNetInterfaces": "kSCPropNetInterfaces",
    "kSCPropNetProxiesFTPPassive": "kSCPropNetProxiesFTPPassive",
    "kSCValNetPPPAuthPasswordEncryptionToken": "kSCValNetPPPAuthPasswordEncryptionToken",
    "kSCValNetIPv4ConfigMethodAutomatic": "kSCValNetIPv4ConfigMethodAutomatic",
    "kSCPropNetPPPDeviceLastCause": "kSCPropNetPPPDeviceLastCause",
    "kSCEntNetIPv4": "kSCEntNetIPv4",
    "kSCPropNetOverridePrimary": "kSCPropNetOverridePrimary",
    "kSCEntNetIPv6": "kSCEntNetIPv6",
    "kSCPropNetPPPIPCPUsePeerDNS": "kSCPropNetPPPIPCPUsePeerDNS",
    "kSCPropNetPPPStatus": "kSCPropNetPPPStatus",
    "kSCPropNetPPPCommUseTerminalScript": "kSCPropNetPPPCommUseTerminalScript",
    "kSCPropNetModemHoldReminderTime": "kSCPropNetModemHoldReminderTime",
    "kSCPropNetPPPLCPMRU": "kSCPropNetPPPLCPMRU",
    "kSCValNetIPv6ConfigMethodLinkLocal": "kSCValNetIPv6ConfigMethodLinkLocal",
}
cftypes = [
    ("SCBondStatusRef", b"^{__SCBondStatus=}", "SCBondStatusGetTypeID", None),
    ("SCDynamicStoreRef", b"^{__SCDynamicStore=}", "SCDynamicStoreGetTypeID", None),
    (
        "SCNetworkConnectionRef",
        b"^{__SCNetworkConnection=}",
        "SCNetworkConnectionGetTypeID",
        None,
    ),
    (
        "SCNetworkInterfaceRef",
        b"^{__SCNetworkInterface=}",
        "SCNetworkInterfaceGetTypeID",
        None,
    ),
    (
        "SCNetworkProtocolRef",
        b"^{__SCNetworkProtocol=}",
        "SCNetworkProtocolGetTypeID",
        None,
    ),
    (
        "SCNetworkReachabilityRef",
        b"^{__SCNetworkReachability=}",
        "SCNetworkReachabilityGetTypeID",
        None,
    ),
    (
        "SCNetworkServiceRef",
        b"^{__SCNetworkService=}",
        "SCNetworkServiceGetTypeID",
        None,
    ),
    ("SCNetworkSetRef", b"^{__SCNetworkSet=}", "SCNetworkSetGetTypeID", None),
    ("SCPreferencesRef", b"^{__SCPreferences=}", "SCPreferencesGetTypeID", None),
]
expressions = {}

# END OF FILE
